@@ -24,9 +24,9 @@
 */
 
 #include "akregatorconfig.h"
+#include "feed.h"
 #include "article.h"
 #include "articlejobs.h"
-#include "feed.h"
 #include "feediconmanager.h"
 #include "feedstorage.h"
 #include "fetchqueue.h"
@@ -414,7 +414,7 @@ QDomElement Feed::toOPML( QDomElement parent, QDomDocument document ) const
     if (d->loadLinkedWebsite)
         el.setAttribute( "loadLinkedWebsite", "true" );
     el.setAttribute( "maxArticleNumber", d->maxArticleNumber );
-    el.setAttribute( "type", "rss" ); // despite some additional fields, its still "rss" OPML
+    el.setAttribute( "type", "rss" ); // despite some additional fields, it is still "rss" OPML
     el.setAttribute( "version", "RSS" );
     parent.appendChild( el );
     return el;
@@ -657,7 +657,7 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
                                 + Utils::fileNameForUrl(d->xmlUrl) + ".png";
         d->imagePixmap=QPixmap(imageFileName, "PNG");
 
-        // if we aint got teh image and the feed provides one, get it....
+        // if we ain't got the image and the feed provides one, get it....
         // TODO: reenable image fetching!
         if (false) // d->imagePixmap.isNull() && doc.image())
         {
@@ -668,7 +668,7 @@ void Feed::fetchCompleted(Syndication::Loader *l, Syndication::FeedPtr doc, Synd
     }
 
     if (title().isEmpty())
-        setTitle( doc->title() );
+        setTitle( Syndication::htmlToPlainText( doc->title() ) );
 
     d->description = doc->description();
     d->htmlUrl = doc->link();
@@ -862,8 +862,7 @@ void Feed::enforceLimitArticleNumber()
     int c = 0;
     const bool useKeep = Settings::doNotExpireImportantArticles();
 
-    ArticleDeleteJob* job = new ArticleDeleteJob;
-    Q_FOREACH ( const Article& i, articles )
+    Q_FOREACH ( Article i, articles )
     {
         if (c < limit)
         {
@@ -872,11 +871,9 @@ void Feed::enforceLimitArticleNumber()
         }
         else if ( !useKeep || !i.keep() )
         {
-            const ArticleId aid = { i.feed()->xmlUrl(), i.guid() };
-            job->appendArticleId( aid );
+            i.setDeleted();
         }
     }
-    job->start();
 }
 
 #include "feed.moc"
