@@ -24,23 +24,21 @@
 #ifndef ADDRESSEDITWIDGET_H
 #define ADDRESSEDITWIDGET_H
 
-#include <QWidget>
-
-#include <KDialog>
+#include <QtGui/QWidget>
 
 #include <kabc/address.h>
 #include <kabc/addressee.h>
+#include <kdialog.h>
 
-#include "addresseeconfig.h"
 #include "typecombo.h"
 
 class QButtonGroup;
 class QCheckBox;
 class QLabel;
-class QTextEdit;
 
 class KComboBox;
 class KLineEdit;
+class KTextEdit;
 
 typedef TypeCombo<KABC::Address, KABC::Address::Type> AddressTypeCombo;
 
@@ -52,7 +50,7 @@ class AddressEditWidget : public QWidget
   Q_OBJECT
 
   public:
-    AddressEditWidget( QWidget *parent, const char *name = 0 );
+    explicit AddressEditWidget( QWidget *parent, const char *name = 0 );
     ~AddressEditWidget();
 
     KABC::Address::List addresses();
@@ -65,10 +63,10 @@ class AddressEditWidget : public QWidget
 
     void setReadOnly( bool readOnly );
 
-  signals:
+  Q_SIGNALS:
     void modified();
 
-  protected slots:
+  protected Q_SLOTS:
     void updateAddressEdit();
 
     void edit();
@@ -99,7 +97,7 @@ class AddressEditDialog : public KDialog
     KABC::Address::List addresses();
     bool changed() const;
 
-  protected slots:
+  protected Q_SLOTS:
     void addAddress();
     void removeAddress();
     void changeType();
@@ -114,7 +112,7 @@ class AddressEditDialog : public KDialog
     QStringList sortLocaleAware( const QStringList& );
 
     AddressTypeCombo *mTypeCombo;
-    QTextEdit *mStreetTextEdit;
+    KTextEdit *mStreetTextEdit;
     KComboBox *mCountryCombo;
     KLineEdit *mRegionEdit;
     KLineEdit *mLocalityEdit;
