@@ -210,7 +210,7 @@ void AddresseeEditorWidget::setupTab1()
 
   mIMWidget = new IMEditWidget( page, mAddressee, tab1.mInetLayout );
   connect( mIMWidget, SIGNAL( modified() ), SLOT( emitModified() ) );
-  tab1.layout->addWidget( mIMWidget, 7, 4, 3, 2 );
+  tab1.layout->addWidget( mIMWidget );
 
   // Categories
   connect( tab1.mCategoryButton, SIGNAL( clicked() ), SLOT( selectCategories() ) );
@@ -223,7 +223,7 @@ void AddresseeEditorWidget::setupTab1()
   // Build the layout and add to the tab widget
   //layout->activate(); // required
 
-  mTabWidget->addTab( page, i18n( "General" ) );
+  mTabWidget->addTab( page, i18nc( "@title:tab General information about a contact", "General" ) );
 }
 
 void AddresseeEditorWidget::setupTab2()
