@@ -24,30 +24,30 @@
 #ifndef ADDRESSEEWIDGET_H
 #define ADDRESSEEWIDGET_H
 
-#include <QWidget>
-
-class KComboBox;
+#include <QtGui/QGroupBox>
 
 class QListWidget;
 class QListWidgetItem;
 class QPushButton;
 
-class NamePartWidget : public QWidget
+class KComboBox;
+
+class NamePartWidget: public QGroupBox
 {
   Q_OBJECT
 
   public:
-    NamePartWidget( const QString &title, const QString &label, QWidget *parent,
+    explicit NamePartWidget( const QString &title, const QString &label, QWidget *parent,
                     const char *name = 0 );
     ~NamePartWidget();
 
     void setNameParts( const QStringList &list );
     QStringList nameParts() const;
 
-  signals:
+  Q_SIGNALS:
     void modified();
 
-  private slots:
+  private Q_SLOTS:
     void add();
     void edit();
     void remove();
@@ -69,13 +69,13 @@ class AddresseeWidget : public QWidget
   Q_OBJECT
 
   public:
-    AddresseeWidget( QWidget *parent, const char *name = 0 );
+    explicit AddresseeWidget( QWidget *parent, const char *name = 0 );
     ~AddresseeWidget();
 
     void restoreSettings();
     void saveSettings();
 
-  signals:
+  Q_SIGNALS:
     void modified();
 
   private:
