@@ -21,9 +21,10 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include <QFile>
-//Added by qt3to4:
-#include <QTextStream>
+#include "csv_xxport.h"
+
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 #include <kfiledialog.h>
 #include <kio/netaccess.h>
@@ -34,8 +35,6 @@
 
 #include "csvimportdialog.h"
 
-#include "csv_xxport.h"
-
 K_EXPORT_KADDRESSBOOK_XXFILTER( kaddrbk_csv_xxport, CSVXXPort )
 
 CSVXXPort::CSVXXPort( KABC::AddressBook *ab, QWidget *parent, const char *name )
@@ -51,6 +50,11 @@ bool CSVXXPort::exportContacts( const KABC::AddresseeList &list, const QString&
   if ( url.isEmpty() )
       return true;
 
+  if( QFileInfo( url.isLocalFile() ? url.toLocalFile() : url.path() ).exists() ) {
+      if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"", url.isLocalFile() ? url.toLocalFile() : url.path()) ) == KMessageBox::No)
+        return true;
+  }
+
   if ( !url.isLocalFile() ) {
     KTemporaryFile tmpFile;
     if ( !tmpFile.open() ) {
@@ -64,9 +68,9 @@ bool CSVXXPort::exportContacts( const KABC::AddresseeList &list, const QString&
 
     return KIO::NetAccess::upload( tmpFile.fileName(), url, parentWidget() );
   } else {
-    QFile file( url.path() );
+    QFile file( url.toLocalFile() );
     if ( !file.open( QIODevice::WriteOnly ) ) {
-      QString txt = i18n( "<qt>Unable to open file <b>%1</b>.</qt>", url.path() );
+      QString txt = i18n( "<qt>Unable to open file <b>%1</b>.</qt>", url.toLocalFile() );
       KMessageBox::error( parentWidget(), txt );
       return false;
     }
@@ -119,7 +123,7 @@ void CSVXXPort::doExport( QFile *fp, const KABC::AddresseeList &list )
       if ( !first )
         t << ",";
 
-      t << "\"" << (*fieldIter)->value( addr ).replace( "\n", "\\n" ) << "\"";
+      t << '\"' << (*fieldIter)->value( addr ).replace( '\n', "\\n" ) << '\"';
       first = false;
     }
 
