@@ -33,30 +33,28 @@
     into your KDE Addressbook.
 */
 
-#include <QFile>
-//Added by qt3to4:
-#include <QTextStream>
+#include "ldif_xxport.h"
 
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+
+#include <kabc/ldifconverter.h>
+#include <kcodecs.h>
+#include <kdebug.h>
 #include <kfiledialog.h>
 #include <kio/netaccess.h>
 #include <klocale.h>
-#include <kcodecs.h>
 #include <kmessagebox.h>
 #include <ktemporaryfile.h>
 #include <kurl.h>
-#include <kabc/ldifconverter.h>
-
-#include <kdebug.h>
-
-#include "ldif_xxport.h"
 
 K_EXPORT_KADDRESSBOOK_XXFILTER( kaddrbk_ldif_xxport, LDIFXXPort )
 
 LDIFXXPort::LDIFXXPort( KABC::AddressBook *ab, QWidget *parent, const char *name )
   : KAB::XXPort( ab, parent, name )
 {
-  createImportAction( i18n( "Import LDIF Addressbook..." ) );
-  createExportAction( i18n( "Export LDIF Addressbook..." ) );
+  createImportAction( i18n( "Import LDIF Address Book..." ) );
+  createExportAction( i18n( "Export LDIF Address Book..." ) );
 }
 
 /* import */
@@ -106,6 +104,11 @@ bool LDIFXXPort::exportContacts( const KABC::AddresseeList &list, const QString&
   if ( url.isEmpty() )
       return true;
 
+  if( QFileInfo( url.isLocalFile() ? url.toLocalFile() : url.path()).exists() ) {
+      if(KMessageBox::questionYesNo( parentWidget(), i18n("Do you want to overwrite file \"%1\"", url.isLocalFile() ? url.toLocalFile() : url.path()) ) == KMessageBox::No)
+	 return true;
+  }
+
   if ( !url.isLocalFile() ) {
     KTemporaryFile tmpFile;
     if ( !tmpFile.open() ) {
@@ -119,7 +122,7 @@ bool LDIFXXPort::exportContacts( const KABC::AddresseeList &list, const QString&
 
     return KIO::NetAccess::upload( tmpFile.fileName(), url, parentWidget() );
   } else {
-    QString filename = url.path();
+    QString filename = url.toLocalFile();
     QFile file( filename );
 
     if ( !file.open( QIODevice::WriteOnly ) ) {
