@@ -1348,32 +1348,6 @@ AlarmResource* AlarmCalendar::resourceForEvent(const QString& eventID) const
 	return AlarmResources::instance()->resourceForIncidence(eventID);
 }
 
-/******************************************************************************
-* Emit a signal to indicate whether the calendar is empty.
-*/
-void AlarmCalendar::emitEmptyStatus()
-{
-	emit emptyStatus(isEmpty());
-}
-
-/******************************************************************************
-* Return whether the calendar contains any events with alarms.
-*/
-bool AlarmCalendar::isEmpty() const
-{
-	if (!mCalendar)
-		return true;
-	Event::List list = mCalendar->rawEvents();
-	if (list.isEmpty())
-		return true;
-	for (int i = 0, end = list.count();  i < end;  ++i)
-	{
-		if (!list[i]->alarms().isEmpty())
-			return false;
-	}
-	return true;
-}
-
 /******************************************************************************
 * Return a list of all active at-login alarms.
 */
@@ -1476,3 +1450,22 @@ void AlarmCalendar::setAlarmPending(KAEvent* event, bool pending)
 	// Now update the earliest alarm to trigger for its resource
 	findEarliestAlarm(AlarmResources::instance()->resourceForIncidence(id));
 }
+
+/******************************************************************************
+* Called when the user changes the start-of-day time.
+* Adjust the start times of all date-only alarms' recurrences.
+*/
+void AlarmCalendar::adjustStartOfDay()
+{
+	if (!mCalendar)
+		return;
+	for (ResourceMap::ConstIterator rit = mResourceMap.constBegin();  rit != mResourceMap.constEnd();  ++rit)
+	{
+		const KAEvent::List events = rit.value();
+		for (int i = 0, end = events.count();  i < end;  ++i)
+		{
+			if (events[i]->startDateTime().isDateOnly()  &&  events[i]->recurs())
+				events[i]->adjustRecurrenceStartOfDay();
+		}
+	}
+}
