@@ -75,12 +75,11 @@ class AlarmCalendar : public QObject
 		KAEvent*              updateEvent(const KAEvent&);
 		KAEvent*              updateEvent(const KAEvent*);
 		bool                  deleteEvent(const QString& eventID, bool save = false);
-		void                  emitEmptyStatus();
 		void                  purgeEvents(const KAEvent::List&);
 		bool                  isOpen() const         { return mOpen; }
-		bool                  isEmpty() const;
 		QString               path() const           { return (mCalType == RESOURCES) ? QString() : mUrl.prettyUrl(); }
 		QString               urlString() const      { return (mCalType == RESOURCES) ? QString() : mUrl.url(); }
+		void                  adjustStartOfDay();
 
 		static QString        icalProductId();
 		static bool           initialiseCalendars();
@@ -96,7 +95,6 @@ class AlarmCalendar : public QObject
 	signals:
 		void                  earliestAlarmChanged();
 		void                  calendarSaved(AlarmCalendar*);
-		void                  emptyStatus(bool empty);
 
 	private slots:
 		void                  setAskResource(bool ask);
