@@ -89,6 +89,7 @@ EventListModel::EventListModel(KCalEvent::Status status, QObject* parent)
 	// We need to store the list so that when deletions occur, the deleted alarm's
 	// position in the list can be determined.
 	mEvents = AlarmCalendar::resources()->events(mStatus);
+	mHaveEvents = !mEvents.isEmpty();
 //for(int x=0; x<mEvents.count(); ++x)kDebug(0)<<"Resource"<<(void*)mEvents[x]->resource()<<"Event"<<(void*)mEvents[x];
 	if (!mTextIcon)
 	{
@@ -619,6 +620,8 @@ void EventListModel::slotResourceStatusChanged(AlarmResource* resource, AlarmRes
 			beginInsertRows(QModelIndex(), row, row + list.count() - 1);
 			mEvents += list;
 			endInsertRows();
+			if (!mHaveEvents)
+				updateHaveEvents(true);
 		}
 	}
 }
@@ -661,6 +664,8 @@ void EventListModel::removeResource(AlarmResource* resource)
 			mEvents.removeAt(lastRow--);
 		endRemoveRows();
 	}
+	if (mHaveEvents  &&  mEvents.isEmpty())
+		updateHaveEvents(false);
 }
 
 /******************************************************************************
@@ -682,6 +687,8 @@ void EventListModel::reload()
 		mEvents = list;
 		endInsertRows();
 	}
+	if (mHaveEvents == mEvents.isEmpty())
+		updateHaveEvents(!mHaveEvents);
 }
 
 /******************************************************************************
@@ -719,6 +726,8 @@ void EventListModel::addEvent(KAEvent* event)
 	beginInsertRows(QModelIndex(), row, row);
 	mEvents += event;
 	endInsertRows();
+	if (!mHaveEvents)
+		updateHaveEvents(true);
 }
 
 /******************************************************************************
@@ -734,6 +743,8 @@ void EventListModel::addEvents(const KAEvent::List& events)
 	beginInsertRows(QModelIndex(), row, row + evs.count() - 1);
 	mEvents += evs;
 	endInsertRows();
+	if (!mHaveEvents)
+		updateHaveEvents(true);
 }
 
 /******************************************************************************
@@ -746,6 +757,8 @@ void EventListModel::removeEvent(int row)
 	beginRemoveRows(QModelIndex(), row, row);
 	mEvents.removeAt(row);
 	endRemoveRows();
+	if (mHaveEvents  &&  mEvents.isEmpty())
+		updateHaveEvents(false);
 }
 
 /******************************************************************************
