@@ -27,6 +27,7 @@
 #include <QMap>
 #include <QPointer>
 
+#include "autoqpointer.h"
 #include "mainwindowbase.h"
 #include "alarmevent.h"
 
@@ -34,12 +35,12 @@ class QShowEvent;
 class QMoveEvent;
 class QResizeEvent;
 class QCloseEvent;
-class QPushButton;
-class KPushButton;
+class PushButton;
 class MessageText;
 class QCheckBox;
 class QLabel;
 class DeferAlarmDlg;
+class EditAlarmDlg;
 class ShellProcess;
 class AudioThread;
 
@@ -63,7 +64,10 @@ class MessageWin : public MainWindowBase
 		void                setRecreating()        { mRecreating = true; }
 		const DateTime&     dateTime()             { return mDateTime; }
 		KAAlarm::Type       alarmType() const      { return mAlarmType; }
-		bool                hasDefer() const       { return mDeferButton; }
+		bool                hasDefer() const;
+		void                showDefer();
+		void                cancelReminder(const KAEvent&, const KAAlarm&);
+		void                showDateTime(const KAEvent&, const KAAlarm&);
 		bool                isValid() const        { return !mInvalid; }
 		virtual void        show();
 		virtual QSize       sizeHint() const;
@@ -86,6 +90,9 @@ class MessageWin : public MainWindowBase
 		void                slotOk();
 		void                slotEdit();
 		void                slotDefer();
+		void                editCloseOk();
+		void                editCloseCancel();
+		void                activeWindowChanged(WId);
 		void                checkDeferralLimit();
 		void                displayMainWindow();
 #ifdef KMAIL_SUPPORTED
@@ -106,7 +113,9 @@ class MessageWin : public MainWindowBase
 		MessageWin(const KAEvent*, const DateTime& alarmDateTime, const QStringList& errmsgs,
 		           const QString& dontShowAgain);
 		void                initView();
+		QString             dateTimeToDisplay();
 		void                displayComplete();
+		void                setButtonsReadOnly(bool);
 		bool                getWorkAreaAndModal();
 		void                playAudio();
 		void                setDeferralLimit(const KAEvent&);
@@ -149,21 +158,23 @@ class MessageWin : public MainWindowBase
 		// Miscellaneous
 		KAEvent             mEvent;           // the whole event, for updating the calendar file
 		AlarmResource*      mResource;        // resource which the event comes/came from
+		QLabel*             mTimeLabel;       // trigger time label
 		QLabel*             mRemainingText;   // the remaining time (for a reminder window)
-		KPushButton*        mOkButton;
-		QPushButton*        mEditButton;
-		QPushButton*        mDeferButton;
-		QPushButton*        mSilenceButton;
-		QPushButton*        mKAlarmButton;
-		QPushButton*        mKMailButton;
+		PushButton*         mOkButton;
+		PushButton*         mEditButton;
+		PushButton*         mDeferButton;
+		PushButton*         mSilenceButton;
+		PushButton*         mKAlarmButton;
+		PushButton*         mKMailButton;
 		MessageText*        mCommandText;     // shows output from command
 		QCheckBox*          mDontShowAgainCheck;
+		EditAlarmDlg*       mEditDlg;         // alarm edit dialog invoked by Edit button
 		DeferAlarmDlg*      mDeferDlg;
 		QDateTime           mDeferLimit;      // last time to which the message can currently be deferred
-		QRect               mDesktopArea;     // usable area of desktop (excluding panel etc.)
 		int                 mFlags;           // event flags
 		int                 mLateCancel;
 		int                 mButtonDelay;     // delay (ms) after window is shown before buttons are enabled
+		int                 mScreenNumber;    // screen to display on, or -1 for default
 		bool                mErrorWindow;     // the window is simply an error message
 		bool                mNoPostAction;    // don't execute any post-alarm action
 		bool                mRecreating;      // window is about to be deleted and immediately recreated
