@@ -1,7 +1,7 @@
 /*
  *  newalarmaction.cpp  -  menu action to select a new alarm type
  *  Program:  kalarm
- *  Copyright © 2007,2008 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2007-2009 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,16 +30,32 @@
 #include <kdebug.h>
 
 
+#define DISP_ICON QLatin1String("window-new")
+#define CMD_ICON  QLatin1String("new-command-alarm")
+#define MAIL_ICON QLatin1String("mail-message-new")
+#define DISP_KEY  QKeySequence(Qt::CTRL + Qt::Key_D)
+#define CMD_KEY   QKeySequence(Qt::CTRL + Qt::Key_C)
+#define MAIL_KEY  QKeySequence(Qt::CTRL + Qt::Key_M)
+
+
 NewAlarmAction::NewAlarmAction(bool templates, const QString& label, QObject* parent)
 	: KActionMenu(KIcon("document-new"), label, parent)
 {
-	setShortcuts(KStandardShortcut::openNew());
-	QAction* act = menu()->addAction(KIcon(QLatin1String("window-new")), (templates ? i18nc("@item:inmenu", "&Display Alarm Template") : i18nc("@item:inmenu", "Display Alarm")));
-	mTypes[act] = EditAlarmDlg::DISPLAY;
-	mCommandAction = menu()->addAction(KIcon(QLatin1String("new-command-alarm")), (templates ? i18nc("@item:inmenu", "&Command Alarm Template") : i18nc("@item:inmenu", "Command Alarm")));
+	mDisplayAction = new KAction(KIcon(DISP_ICON), (templates ? i18nc("@item:inmenu", "&Display Alarm Template") : i18nc("@action", "New Display Alarm")), parent);
+	menu()->addAction(mDisplayAction);
+	mTypes[mDisplayAction] = EditAlarmDlg::DISPLAY;
+	mCommandAction = new KAction(KIcon(CMD_ICON), (templates ? i18nc("@item:inmenu", "&Command Alarm Template") : i18nc("@action", "New Command Alarm")), parent);
+	menu()->addAction(mCommandAction);
 	mTypes[mCommandAction] = EditAlarmDlg::COMMAND;
-	act = menu()->addAction(KIcon(QLatin1String("mail-message-new")), (templates ? i18nc("@item:inmenu", "&Email Alarm Template") : i18nc("@item:inmenu", "Email Alarm")));
-	mTypes[act] = EditAlarmDlg::EMAIL;
+	mEmailAction = new KAction(KIcon(MAIL_ICON), (templates ? i18nc("@item:inmenu", "&Email Alarm Template") : i18nc("@action", "New Email Alarm")), parent);
+	menu()->addAction(mEmailAction);
+	mTypes[mEmailAction] = EditAlarmDlg::EMAIL;
+	if (!templates)
+	{
+		mDisplayAction->setShortcut(DISP_KEY);
+		mCommandAction->setShortcut(CMD_KEY);
+		mEmailAction->setShortcut(MAIL_KEY);
+	}
 	setDelayed(false);
 	connect(menu(), SIGNAL(aboutToShow()), SLOT(slotInitMenu()));
 	connect(menu(), SIGNAL(triggered(QAction*)), SLOT(slotSelected(QAction*)));
@@ -59,7 +75,7 @@ void NewAlarmAction::slotInitMenu()
 */
 void NewAlarmAction::slotSelected(QAction* action)
 {
-	QMap<QAction*, EditAlarmDlg::Type>::const_iterator it = mTypes.find(action);
-	if (it != mTypes.end())
+	QMap<QAction*, EditAlarmDlg::Type>::ConstIterator it = mTypes.constFind(action);
+	if (it != mTypes.constEnd())
 		emit selected(it.value());
 }
