@@ -1,7 +1,7 @@
 /*
  *  recurrenceeditprivate.h  -  private classes for recurrenceedit.cpp
  *  Program:  kalarm
- *  Copyright © 2003,2005,2007 by David Jarvie <software@astrojar.org.uk>
+ *  Copyright © 2003,2005,2007,2009 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,10 +21,11 @@
 #ifndef RECURRENCEEDITPRIVATE_H
 #define RECURRENCEEDITPRIVATE_H
 
-#include <qframe.h>
-#include <qvaluelist.h>
-#include <qbitarray.h>
+#include <QList>
+#include <QFrame>
+#include <QBitArray>
 
+class QLabel;
 class QWidget;
 class QVBoxLayout;
 class ButtonGroup;
@@ -39,8 +40,7 @@ class QString;
 class NoRule : public QFrame
 {
 	public:
-		NoRule(QWidget* parent, const char* name = 0) : QFrame(parent, name)
-		                                                 { setFrameStyle(QFrame::NoFrame); }
+		explicit NoRule(QWidget* parent) : QFrame(parent) { }
 		virtual int      frequency() const       { return 0; }
 };
 
@@ -49,7 +49,7 @@ class Rule : public NoRule
 		Q_OBJECT
 	public:
 		Rule(const QString& freqText, const QString& freqWhatsThis, bool time, bool readOnly,
-		     QWidget* parent, const char* name = 0);
+		     QWidget* parent);
 		int              frequency() const;
 		void             setFrequency(int);
 		virtual void     setFrequencyFocus()     { mSpinBox->setFocus(); }
@@ -59,6 +59,7 @@ class Rule : public NoRule
 		virtual bool     stateChanged() const;
 	signals:
 		void             frequencyChanged();
+		void             changed();          // emitted whenever any control changes
 	private:
 		QWidget*         mSpinBox;
 		SpinBox*         mIntSpinBox;
@@ -73,7 +74,7 @@ class SubDailyRule : public Rule
 {
 		Q_OBJECT
 	public:
-		SubDailyRule(bool readOnly, QWidget* parent, const char* name = 0);
+		SubDailyRule(bool readOnly, QWidget* parent);
 };
 
 // Daily/weekly rule choices base class
@@ -82,7 +83,7 @@ class DayWeekRule : public Rule
 		Q_OBJECT
 	public:
 		DayWeekRule(const QString& freqText, const QString& freqWhatsThis, const QString& daysWhatsThis,
-		            bool readOnly, QWidget* parent, const char* name = 0);
+		            bool readOnly, QWidget* parent);
 		QBitArray        days() const;
 		void             setDays(bool);
 		void             setDays(const QBitArray& days);
@@ -100,14 +101,14 @@ class DayWeekRule : public Rule
 class DailyRule : public DayWeekRule
 {
 	public:
-		DailyRule(bool readOnly, QWidget* parent, const char* name = 0);
+		DailyRule(bool readOnly, QWidget* parent);
 };
 
 // Weekly rule choices
 class WeeklyRule : public DayWeekRule
 {
 	public:
-		WeeklyRule(bool readOnly, QWidget* parent, const char* name = 0);
+		WeeklyRule(bool readOnly, QWidget* parent);
 };
 
 // Monthly/yearly rule choices base class
@@ -118,7 +119,7 @@ class MonthYearRule : public Rule
 		enum DayPosType { DATE, POS };
 
 		MonthYearRule(const QString& freqText, const QString& freqWhatsThis, bool allowEveryWeek,
-		              bool readOnly, QWidget* parent, const char* name = 0);
+		              bool readOnly, QWidget* parent);
 		DayPosType       type() const;
 		int              date() const;       // if date in month is selected
 		int              week() const;       // if position is selected
@@ -132,10 +133,10 @@ class MonthYearRule : public Rule
 	signals:
 		void             typeChanged(DayPosType);
 	protected:
-		DayPosType       buttonType(int id) const  { return id == mDayButtonId ? DATE : POS; }
+		DayPosType       buttonType(QAbstractButton* b) const  { return b == mDayButton ? DATE : POS; }
 		virtual void     daySelected(int /*day*/)  { }
 	protected slots:
-		virtual void     clicked(int id);
+		virtual void     clicked(QAbstractButton*);
 	private slots:
 		virtual void     slotDaySelected(int index);
 	private:
@@ -147,8 +148,6 @@ class MonthYearRule : public Rule
 		ComboBox*        mDayCombo;
 		ComboBox*        mWeekCombo;
 		ComboBox*        mDayOfWeekCombo;
-		int              mDayButtonId;
-		int              mPosButtonId;
 		bool             mEveryWeek;         // "Every" week is allowed
 		// Saved state of all controls
 		int              mSavedType;         // whether day-of-month or month position radio button was selected
@@ -161,7 +160,7 @@ class MonthYearRule : public Rule
 class MonthlyRule : public MonthYearRule
 {
 	public:
-		MonthlyRule(bool readOnly, QWidget* parent, const char* name = 0);
+		MonthlyRule(bool readOnly, QWidget* parent);
 };
 
 // Yearly rule choices
@@ -169,19 +168,19 @@ class YearlyRule : public MonthYearRule
 {
 		Q_OBJECT
 	public:
-		YearlyRule(bool readOnly, QWidget* parent, const char* name = 0);
-		QValueList<int>  months() const;
-		void             setMonths(const QValueList<int>& months);
+		YearlyRule(bool readOnly, QWidget* parent);
+		QList<int>       months() const;
+		void             setMonths(const QList<int>& months);
 		void             setDefaultValues(int dayOfMonth, int dayOfWeek, int month);
-		KARecurrence::Feb29Type feb29Type() const;
-		void             setFeb29Type(KARecurrence::Feb29Type);
+		Preferences::Feb29Type feb29Type() const;
+		void             setFeb29Type(Preferences::Feb29Type);
 		virtual QWidget* validate(QString& errorMessage);
 		virtual void     saveState();
 		virtual bool     stateChanged() const;
 	protected:
 		virtual void     daySelected(int day);
 	protected slots:
-		virtual void     clicked(int id);
+		virtual void     clicked(QAbstractButton*);
 	private slots:
 		void             enableFeb29();
 	private:
@@ -189,7 +188,7 @@ class YearlyRule : public MonthYearRule
 		QLabel*          mFeb29Label;
 		ComboBox*        mFeb29Combo;
 		// Saved state of all controls
-		QValueList<int>  mSavedMonths;       // ticked months for yearly rule
+		QList<int>       mSavedMonths;       // ticked months for yearly rule
 		int              mSavedFeb29Type;    // February 29th recurrence type
 };
 
