@@ -33,12 +33,12 @@
 #include <config-kleopatra.h>
 
 #include "tabwidget.h"
+#include "keytreeview.h"
 
 #include <models/keylistmodel.h>
 #include <models/keylistsortfilterproxymodel.h>
 
 #include <utils/action_data.h>
-#include <utils/headerview.h>
 #include <utils/stl_util.h>
 
 #include <kleo/keyfilter.h>
@@ -60,9 +60,6 @@
 #include <QAction>
 #include <QMenu>
 #include <QInputDialog>
-#include <QItemSelectionModel>
-#include <QItemSelection>
-#include <QLayout>
 
 #include <map>
 #include <vector>
@@ -74,47 +71,27 @@ using namespace GpgME;
 
 namespace {
 
-class TreeView : public QTreeView {
-public:
-    explicit TreeView( QWidget * parent=0 ) : QTreeView( parent ) {}
-
-    /* reimp */ QSize minimumSizeHint() const {
-        const QSize min = QTreeView::minimumSizeHint();
-        return QSize( min.width(), min.height() + 5 * fontMetrics().height() );
-    }
-};
-
-class Page : public QWidget {
+class Page : public Kleo::KeyTreeView {
     Q_OBJECT
     Page( const Page & other );
 public:
-    Page( const QString & title, const QString & id, const QString & text, AbstractKeyListSortFilterProxyModel * proxy=0, QWidget * parent=0 );
+    Page( const QString & title, const QString & id, const QString & text, AbstractKeyListSortFilterProxyModel * proxy=0, const QString & toolTip=QString(), QWidget * parent=0 );
     Page( const KConfigGroup & group, QWidget * parent=0 );
     ~Page();
 
-    QTreeView * view() const { return m_view; }
-
-    AbstractKeyListModel * model() const {
-        return m_isHierarchical ? m_hierarchicalModel : m_flatModel ;
-    }
-    void setFlatModel( AbstractKeyListModel * model );
-    void setHierarchicalModel( AbstractKeyListModel * model );
-
     void setTemporary( bool temporary );
     bool isTemporary() const { return m_isTemporary; }
 
-    void setHierarchical( bool hierarchical );
-    bool isHierarchical() const { return m_isHierarchical; }
+    /* reimp */ void setHierarchicalView( bool hierarchical );
+    /* reimp */ void setStringFilter( const QString & filter ); 
+    /* reimp */ void setKeyFilter( const shared_ptr<KeyFilter> & filter );
 
-    QString stringFilter() const { return m_stringFilter; }
-    void setStringFilter( const QString & filter ); 
-
-    const shared_ptr<KeyFilter> & keyFilter() const { return m_keyFilter; }
-    void setKeyFilter( const shared_ptr<KeyFilter> & filter );
-
-    QString title() const { return m_title.isEmpty() && m_keyFilter ? m_keyFilter->name() : m_title ; }
+    QString title() const { return m_title.isEmpty() && keyFilter() ? keyFilter()->name() : m_title ; }
     void setTitle( const QString & title );
 
+    QString toolTip() const { return m_toolTip.isEmpty() ? title() : m_toolTip ; }
+    void setToolTip( const QString & tip );
+
     bool canBeClosed() const { return m_canBeClosed; }
     bool canBeRenamed() const { return m_canBeRenamed; }
     bool canChangeStringFilter() const { return m_canChangeStringFilter; }
@@ -123,7 +100,7 @@ public:
 
     void saveTo( KConfigGroup & group ) const;
 
-    Page * clone() const { return new Page( *this ); }
+    /* reimp */ Page * clone() const { return new Page( *this ); }
 
     void liftAllRestrictions() {
         m_canBeClosed = m_canBeRenamed = m_canChangeStringFilter = m_canChangeKeyFilter = m_canChangeHierarchical = true;
@@ -131,25 +108,13 @@ public:
 
 Q_SIGNALS:
     void titleChanged( const QString & title );
-    void stringFilterChanged( const QString & filter );
-    void keyFilterChanged( const boost::shared_ptr<Kleo::KeyFilter> & filter );
-    void hierarchicalChanged( bool on );
 
 private:
     void init();
 
 private:
-    KeyListSortFilterProxyModel m_proxy;
-    AbstractKeyListSortFilterProxyModel * m_additionalProxy;
-    QVBoxLayout * m_layout;
-    QTreeView * m_view;
-    AbstractKeyListModel * m_flatModel;
-    AbstractKeyListModel * m_hierarchicalModel;
-
-    QString m_stringFilter;
-    shared_ptr<KeyFilter> m_keyFilter;
     QString m_title;
-    bool m_isHierarchical : 1;
+    QString m_toolTip;
     bool m_isTemporary : 1;
     bool m_canBeClosed : 1;
     bool m_canBeRenamed : 1;
@@ -160,17 +125,9 @@ private:
 } // anon namespace
 
 Page::Page( const Page & other )
-    : QWidget( 0 ),
-      m_proxy(),
-      m_additionalProxy( other.m_additionalProxy ? other.m_additionalProxy->clone() : 0 ),
-      m_layout( new QVBoxLayout( this ) ),
-      m_view( new TreeView( this ) ),
-      m_flatModel( other.m_flatModel ),
-      m_hierarchicalModel( other.m_hierarchicalModel ),
-      m_stringFilter( other.m_stringFilter ),
-      m_keyFilter( other.m_keyFilter ),
+    : KeyTreeView( other ),
       m_title( other.m_title ),
-      m_isHierarchical( other.m_isHierarchical ),
+      m_toolTip( other.m_toolTip ),
       m_isTemporary( other.m_isTemporary ),
       m_canBeClosed( other.m_canBeClosed ),
       m_canBeRenamed( other.m_canBeRenamed ),
@@ -181,18 +138,10 @@ Page::Page( const Page & other )
     init();
 }
 
-Page::Page( const QString & title, const QString & id, const QString & text, AbstractKeyListSortFilterProxyModel * proxy, QWidget * parent )
-    : QWidget( parent ),
-      m_proxy(),
-      m_additionalProxy( proxy ),
-      m_layout( new QVBoxLayout( this ) ),
-      m_view( new TreeView( this ) ),
-      m_flatModel( 0 ),
-      m_hierarchicalModel( 0 ),
-      m_stringFilter( text ),
-      m_keyFilter( KeyFilterManager::instance()->keyFilterByID( id ) ),
+Page::Page( const QString & title, const QString & id, const QString & text, AbstractKeyListSortFilterProxyModel * proxy, const QString & toolTip, QWidget * parent )
+    : KeyTreeView( text, KeyFilterManager::instance()->keyFilterByID( id ), proxy, parent ),
       m_title( title ),
-      m_isHierarchical( true ),
+      m_toolTip( toolTip ),
       m_isTemporary( false ),
       m_canBeClosed( true ),
       m_canBeRenamed( true ),
@@ -208,19 +157,15 @@ static const char STRING_FILTER_ENTRY[] = "string-filter";
 static const char KEY_FILTER_ENTRY[] = "key-filter";
 static const char HIERARCHICAL_VIEW_ENTRY[] = "hierarchical-view";
 static const char COLUMN_SIZES[] = "column-sizes";
+static const char SORT_COLUMN[] = "sort-column";
+static const char SORT_DESCENDING[] = "sort-descending";
 
 Page::Page( const KConfigGroup & group, QWidget * parent )
-    : QWidget( parent ),
-      m_proxy(),
-      m_additionalProxy( 0 ),
-      m_layout( new QVBoxLayout( this ) ),
-      m_view( new TreeView( this ) ),
-      m_flatModel( 0 ),
-      m_hierarchicalModel( 0 ),
-      m_stringFilter( group.readEntry( STRING_FILTER_ENTRY ) ),
-      m_keyFilter( KeyFilterManager::instance()->keyFilterByID( group.readEntry( KEY_FILTER_ENTRY ) ) ),
+    : KeyTreeView( group.readEntry( STRING_FILTER_ENTRY ),
+                   KeyFilterManager::instance()->keyFilterByID( group.readEntry( KEY_FILTER_ENTRY ) ),
+                   0, parent ),
       m_title( group.readEntry( TITLE_ENTRY ) ),
-      m_isHierarchical( group.readEntry( HIERARCHICAL_VIEW_ENTRY, true ) ),
+      m_toolTip(),
       m_isTemporary( false ),
       m_canBeClosed( !group.isImmutable() ),
       m_canBeRenamed( !group.isEntryImmutable( TITLE_ENTRY ) ),
@@ -229,124 +174,41 @@ Page::Page( const KConfigGroup & group, QWidget * parent )
       m_canChangeHierarchical( !group.isEntryImmutable( HIERARCHICAL_VIEW_ENTRY ) )
 {
     init();
-    assert( m_view );
-    assert( m_view->header() );
-    assert( qobject_cast<HeaderView*>( m_view->header() ) == static_cast<HeaderView*>( m_view->header() ) );
-    if ( HeaderView * const hv = static_cast<HeaderView*>( m_view->header() ) ) {
-        const QList<int> sizes = group.readEntry( COLUMN_SIZES, QList<int>() );
-        if ( !sizes.empty() )
-            hv->setSectionSizes( kdtools::copy< std::vector<int> >( sizes ) );
-    }
-}
-
-static const QHeaderView::ResizeMode resize_modes[AbstractKeyListModel::NumColumns] = {
-    QHeaderView::Stretch,          // Name
-    QHeaderView::Stretch, // EMail
-    QHeaderView::Fixed, // Valid From
-    QHeaderView::Fixed, // Valid Until
-    QHeaderView::Fixed, // Details
-    QHeaderView::Fixed, // Fingerprint
-};
-
-static void adjust_header( HeaderView * hv ) {
-    for ( int i = 0, end = AbstractKeyListModel::NumColumns ; i < end ; ++i )
-        hv->setSectionResizeMode( i, resize_modes[i] );
+    setHierarchicalView( group.readEntry( HIERARCHICAL_VIEW_ENTRY, true ) );
+    setColumnSizes( kdtools::copy< std::vector<int> >( group.readEntry( COLUMN_SIZES, QList<int>() ) ) );
+    setSortColumn(  group.readEntry( SORT_COLUMN, 0 ),
+                    group.readEntry( SORT_DESCENDING, true ) ? Qt::DescendingOrder : Qt::AscendingOrder );
 }
 
 void Page::init() {
-    KDAB_SET_OBJECT_NAME( m_proxy );
-    KDAB_SET_OBJECT_NAME( m_layout );
-    KDAB_SET_OBJECT_NAME( m_view );
-    if ( m_additionalProxy && m_additionalProxy->objectName().isEmpty() )
-        KDAB_SET_OBJECT_NAME( m_additionalProxy );
 
-    m_layout->setMargin( 0 );
-    m_layout->addWidget( m_view );
-
-    HeaderView * headerView = new HeaderView( Qt::Horizontal );
-    KDAB_SET_OBJECT_NAME( headerView );
-    m_view->setHeader( headerView );
-    adjust_header( headerView );
-
-    m_view->setSelectionBehavior( QAbstractItemView::SelectRows );
-    m_view->setSelectionMode( QAbstractItemView::ExtendedSelection );
-    //m_view->setAlternatingRowColors( true );
-    m_view->setAllColumnsShowFocus( true );
-    m_view->setSortingEnabled( true );
-
-    if ( model() ) {
-        if ( m_additionalProxy )
-            m_additionalProxy->setSourceModel( model() );
-        else
-            m_proxy.setSourceModel( model() );
-    }
-    if ( m_additionalProxy ) {
-        m_proxy.setSourceModel( m_additionalProxy );
-        if ( !m_additionalProxy->parent() )
-            m_additionalProxy->setParent( this );
-    }
-    m_proxy.setFilterFixedString( m_stringFilter );
-    m_proxy.setKeyFilter( m_keyFilter );
-    m_view->setModel( &m_proxy );
 }
 
 Page::~Page() {}
 
 void Page::saveTo( KConfigGroup & group ) const {
 
-    group.writeEntry( TITLE_ENTRY, m_title );
-    group.writeEntry( STRING_FILTER_ENTRY, m_stringFilter );
-    group.writeEntry( KEY_FILTER_ENTRY, m_keyFilter ? m_keyFilter->id() : QString() );
-    group.writeEntry( HIERARCHICAL_VIEW_ENTRY, m_isHierarchical );
-    if ( const HeaderView * const hv = m_view ? qobject_cast<HeaderView*>( m_view->header() ) : 0 )
-        group.writeEntry( COLUMN_SIZES, kdtools::copy< QList<int> >( hv->sectionSizes() ) );
-}
-
-static QAbstractProxyModel * find_last_proxy( QAbstractProxyModel * pm ) {
-    assert( pm );
-    while ( QAbstractProxyModel * const sm = qobject_cast<QAbstractProxyModel*>( pm->sourceModel() ) )
-        pm = sm;
-    return pm;
-}
-
-void Page::setFlatModel( AbstractKeyListModel * model ) {
-    if ( model == m_flatModel )
-        return;
-    m_flatModel = model;
-    if ( !m_isHierarchical )
-        find_last_proxy( &m_proxy )->setSourceModel( model );
-}
-
-void Page::setHierarchicalModel( AbstractKeyListModel * model ) {
-    if ( model == m_hierarchicalModel )
-        return;
-    m_hierarchicalModel = model;
-    if ( m_isHierarchical ) {
-        find_last_proxy( &m_proxy )->setSourceModel( model );
-        m_view->expandAll();
-    }
+    group.writeEntry( TITLE_ENTRY,         m_title );
+    group.writeEntry( STRING_FILTER_ENTRY, stringFilter() );
+    group.writeEntry( KEY_FILTER_ENTRY,    keyFilter() ? keyFilter()->id() : QString() );
+    group.writeEntry( HIERARCHICAL_VIEW_ENTRY, isHierarchicalView() );
+    group.writeEntry( COLUMN_SIZES,        kdtools::copy< QList<int> >( columnSizes() ) );
+    group.writeEntry( SORT_COLUMN,         sortColumn() );
+    group.writeEntry( SORT_DESCENDING,     sortOrder() == Qt::DescendingOrder );
 }
 
 void Page::setStringFilter( const QString & filter ) {
-    if ( filter == m_stringFilter )
-        return;
     if ( !m_canChangeStringFilter )
         return;
-    m_stringFilter = filter;
-    m_proxy.setFilterFixedString( filter ); 
-    emit stringFilterChanged( filter );
+    KeyTreeView::setStringFilter( filter );
 }
 
 void Page::setKeyFilter( const shared_ptr<KeyFilter> & filter ) {
-    if ( filter == m_keyFilter || ( filter && m_keyFilter && filter->id() == m_keyFilter->id() ) )
-        return;
     if ( !canChangeKeyFilter() )
         return;
     const QString oldTitle = title();
-    m_keyFilter = filter;
-    m_proxy.setKeyFilter( filter );
+    KeyTreeView::setKeyFilter( filter );
     const QString newTitle = title();
-    emit keyFilterChanged( filter );
     if ( oldTitle != newTitle )
         emit titleChanged( newTitle );
 }
@@ -363,47 +225,30 @@ void Page::setTitle( const QString & t ) {
         emit titleChanged( newTitle );
 }
 
-static QItemSelection itemSelectionFromKeys( const std::vector<Key> & keys, const KeyListSortFilterProxyModel & proxy ) {
-    QItemSelection result;
-    Q_FOREACH( const Key & key, keys ) {
-        const QModelIndex mi = proxy.index( key );
-        if ( mi.isValid() )
-            result.merge( QItemSelection( mi, mi ), QItemSelectionModel::Select );
-    }
-    return result;
+void Page::setToolTip( const QString & tip ) {
+    if ( tip == m_toolTip )
+        return;
+    if ( !m_canBeRenamed )
+        return;
+    const QString oldTip = toolTip();
+    m_toolTip = tip;
+    const QString newTip = toolTip();
+    if ( oldTip != newTip )
+        emit titleChanged( title() );
 }
 
-void Page::setHierarchical( bool on ) {
-    if ( on == m_isHierarchical )
-        return;
+void Page::setHierarchicalView( bool on ) {
     if ( !m_canChangeHierarchical )
         return;
-    const std::vector<Key> selectedKeys = m_proxy.keys( m_view->selectionModel()->selectedRows() );
-    const Key currentKey = m_proxy.key( m_view->currentIndex() );
-
-    m_isHierarchical = on;
-    find_last_proxy( &m_proxy )->setSourceModel( model() );
-    if ( on )
-        m_view->expandAll();
-    m_view->selectionModel()->select( itemSelectionFromKeys( selectedKeys, m_proxy ), QItemSelectionModel::ClearAndSelect | QItemSelectionModel::Rows );
-    if ( !currentKey.isNull() ) {
-        const QModelIndex currentIndex = m_proxy.index( currentKey );
-        if ( currentIndex.isValid() ) {
-            m_view->selectionModel()->setCurrentIndex( m_proxy.index( currentKey ), QItemSelectionModel::NoUpdate );
-            m_view->scrollTo( currentIndex );
-        }
-    }
-    emit hierarchicalChanged( on );
+    KeyTreeView::setHierarchicalView( on );
 }
 
 void Page::setTemporary( bool on ) {
     if ( on == m_isTemporary )
         return;
     m_isTemporary = on;
-    if ( on && m_keyFilter ) {
-        m_keyFilter.reset();
-        emit keyFilterChanged( shared_ptr<KeyFilter>() );
-    }
+    if ( on )
+        setKeyFilter( shared_ptr<KeyFilter>() );
 }
 
 //
@@ -488,7 +333,7 @@ private:
         return sp && sp == currentPage();
     }
 
-    QTreeView * addView( Page * page );
+    QTreeView * addView( Page * page, Page * columnReference );
     void setCornerAction( QAction * action, Qt::Corner corner );
 
 private:
@@ -527,7 +372,7 @@ TabWidget::Private::Private( TabWidget * qq )
     layout.addWidget( &tabWidget );
 
     tabWidget.setTabBarHidden( true );
-    tabWidget.setTabReorderingEnabled( true );
+    tabWidget.setMovable( true );
 
     connect( &tabWidget, SIGNAL(currentChanged(int)),
              q, SLOT(currentIndexChanged(int)) );
@@ -546,7 +391,7 @@ TabWidget::Private::Private( TabWidget * qq )
     struct action_data actionData[NumPageActions] = {
         { "window_rename_tab", i18n("Rename Tab..."), i18n("Rename this tab"),
           "edit-rename", q, SLOT(slotRenameCurrentTab()), i18n("CTRL+SHIFT+R"), false, false },
-        { "window_duplicate_tab", i18n("Duplicate Current Tab"), i18n("Duplicate the current tab"),
+        { "window_duplicate_tab", i18n("Duplicate Tab"), i18n("Duplicate this tab"),
           "tab-duplicate", q, SLOT(slotDuplicateCurrentTab()), i18n("CTRL+SHIFT+D"), false, true },
         { "window_close_tab", i18n("Close Tab"), i18n("Close this tab"),
           "tab-close", q, SLOT(slotCloseCurrentTab()), i18n("CTRL+SHIFT+W"), false, false }, // ### CTRL-W when available
@@ -642,14 +487,19 @@ void TabWidget::Private::enableDisablePageActions( QAction * actions[], const Pa
     actions[MoveLeft]    ->setEnabled( p && tabWidget.indexOf( const_cast<Page*>(p) ) != 0 );
     actions[MoveRight]   ->setEnabled( p && tabWidget.indexOf( const_cast<Page*>(p) ) != tabWidget.count()-1 );
     actions[Hierarchical]->setEnabled( p && p->canChangeHierarchical() );
-    actions[Hierarchical]->setChecked( p && p->isHierarchical() );
-    actions[ExpandAll]   ->setEnabled( p && p->isHierarchical() );
-    actions[CollapseAll] ->setEnabled( p && p->isHierarchical() );
+    actions[Hierarchical]->setChecked( p && p->isHierarchicalView() );
+    actions[ExpandAll]   ->setEnabled( p && p->isHierarchicalView() );
+    actions[CollapseAll] ->setEnabled( p && p->isHierarchicalView() );
+
+    tabWidget.setTabBarHidden( tabWidget.count() < 2 );
 }
 
 void TabWidget::Private::slotPageTitleChanged( const QString & ) {
-    if ( Page * const page = senderPage() )
-        tabWidget.setTabText( tabWidget.indexOf( page ), page->title() );
+    if ( Page * const page = senderPage() ) {
+        const int idx = tabWidget.indexOf( page );
+        tabWidget.setTabText( idx, page->title() );
+        tabWidget.setTabToolTip( idx, page->toolTip() );
+    }
 }
 
 void TabWidget::Private::slotPageKeyFilterChanged( const shared_ptr<KeyFilter> & kf ) {
@@ -667,7 +517,8 @@ void TabWidget::Private::slotPageHierarchyChanged( bool ) {
 }
 
 void TabWidget::Private::slotNewTab() {
-    q->addView( QString(), "all-certificates" );
+    Page * page = new Page( QString(), "all-certificates", QString() );
+    addView( page, currentPage() );
     tabWidget.setCurrentIndex( tabWidget.count()-1 );
 }
 
@@ -687,7 +538,7 @@ void TabWidget::Private::duplicatePage( Page * page ) {
     Page * const clone = page->clone();
     assert( clone );
     clone->liftAllRestrictions();
-    addView( clone );
+    addView( clone, page );
 }
 
 void TabWidget::Private::closePage( Page * page) {
@@ -721,7 +572,7 @@ void TabWidget::Private::movePageRight( Page * page ) {
 void TabWidget::Private::toggleHierarchicalView( Page * page, bool on ) {
     if ( !page )
         return;
-    page->setHierarchical( on );
+    page->setHierarchicalView( on );
 }
 
 void TabWidget::Private::expandAll( Page * page ) {
@@ -817,22 +668,22 @@ void TabWidget::createActions( KActionCollection * coll ) {
 }
 
 QAbstractItemView * TabWidget::addView( const QString & title, const QString & id, const QString & text ) {
-    return d->addView( new Page( title, id, text ) );
+    return d->addView( new Page( title, id, text ), d->currentPage() );
 }
 
 QAbstractItemView * TabWidget::addView( const KConfigGroup & group ) {
-    return d->addView( new Page( group ) );
+    return d->addView( new Page( group ), 0 );
 }
 
-QAbstractItemView * TabWidget::addTemporaryView( const QString & title, AbstractKeyListSortFilterProxyModel * proxy ) {
-    Page * const page = new Page( title, QString(), QString(), proxy );
+QAbstractItemView * TabWidget::addTemporaryView( const QString & title, AbstractKeyListSortFilterProxyModel * proxy, const QString & tabToolTip ) {
+    Page * const page = new Page( title, QString(), QString(), proxy, tabToolTip );
     page->setTemporary( true );
-    QAbstractItemView * v = d->addView( page );
+    QAbstractItemView * v = d->addView( page, d->currentPage() );
     d->tabWidget.setCurrentIndex( d->tabWidget.count()-1 );
     return v;
 }
 
-QTreeView * TabWidget::Private::addView( Page * page ) {
+QTreeView * TabWidget::Private::addView( Page * page, Page * columnReference ) {
     if ( !page )
         return 0;
 
@@ -848,9 +699,14 @@ QTreeView * TabWidget::Private::addView( Page * page ) {
     connect( page, SIGNAL(hierarchicalChanged(bool)),
              q, SLOT(slotPageHierarchyChanged(bool)) );
 
+    if ( columnReference ) {
+        page->setColumnSizes( columnReference->columnSizes() );
+        page->setSortColumn( columnReference->sortColumn(), columnReference->sortOrder() );
+    }
+
     QAbstractItemView * const previous = q->currentView(); 
-    tabWidget.addTab( page, page->title() );
-    tabWidget.setTabBarHidden( tabWidget.count() < 2 );
+    const int tabIndex = tabWidget.addTab( page, page->title() );
+    tabWidget.setTabToolTip( tabIndex, page->toolTip() );
     // work around a bug in QTabWidget (tested with 4.3.2) not emitting currentChanged() when the first widget is inserted
     QAbstractItemView * const current = q->currentView(); 
     if ( previous != current )
