@@ -420,11 +420,11 @@ QString AccountWizard::accountName() const
 
 QLabel *AccountWizard::createInfoLabel( const QString &msg )
 {
-  QLabel *label = new QLabel( msg, this );
+  QLabel *label = new QLabel( msg, this, Qt::Popup );
   label->setFrameStyle( QFrame::Panel | QFrame::Raised );
   label->setLineWidth( 3 );
   label->resize( fontMetrics().width( msg ) + 20, label->height() * 2 );
-  label->move( width() / 2 - label->width() / 2, height() / 2 - label->height() / 2 );
+  label->move( x() + width() / 2 - label->width() / 2, y() + height() / 2 - label->height() / 2 );
   label->setAutoFillBackground( true );
   label->show();
 
@@ -478,7 +478,7 @@ void AccountWizard::createTransport()
     if ( pathToSendmail.isEmpty() ) {
       pathToSendmail = KStandardDirs::findExe( "sendmail", "/usr/sbin" );
       if ( pathToSendmail.isEmpty() ) {
-        kWarning(5006) <<"Could not find the sendmail binary for local delivery";
+        kWarning() <<"Could not find the sendmail binary for local delivery";
         // setting the path to the most likely location
         pathToSendmail = "/usr/sbin/sendmail";
       }
