@@ -39,32 +39,30 @@
 #ifndef FOLDERSHORTCUTDIALOG_H
 #define FOLDERSHORTCUTDIALOG_H
 
-#include <kdialogbase.h> // include for the base class
-class KShortcut;
+#include <kdialog.h> // include for the base class
 class KMFolder;
-class KKeyButton;
+class KKeySequenceWidget;
 class KMMainWidget;
 
 namespace KMail
 {
 
-class FolderShortcutDialog : public KDialogBase
+class FolderShortcutDialog : public KDialog
 {
 Q_OBJECT
 public:
-	FolderShortcutDialog( KMFolder *folder, KMMainWidget *mw, 
-                        QWidget *parent=0, const char *name=0 );
-	~FolderShortcutDialog();
+  FolderShortcutDialog( KMFolder *folder, KMMainWidget *mw,
+                        QWidget *parent=0 );
+  ~FolderShortcutDialog();
 
 
 protected slots:
   void slotOk();
-  void slotCapturedShortcut( const KShortcut& );
 
 private:
   KMFolder *mFolder;
   KMMainWidget *mMainWidget;
-  KKeyButton *mKeyButton;
+  KKeySequenceWidget *mKeySeqWidget;
 
 }; // End of class FolderShortcutDialog
 
