@@ -34,15 +34,13 @@
 // other KMail headers:
 #include "xfaceconfigurator.h"
 #include "folderrequester.h"
-//Added by qt3to4:
-#include <QVBoxLayout>
-#include <QGridLayout>
 using KMail::FolderRequester;
 #include "kmfoldermgr.h"
 #include "mainfolderview.h"
 #include "kleo_util.h"
 #include "kmmainwidget.h"
 #include "kmfolder.h"
+#include "stringutil.h"
 #include "templatesconfiguration.h"
 #include "templatesconfiguration_kfg.h"
 
@@ -79,6 +77,8 @@ using MailTransport::TransportManager;
 #include <QLayout>
 #include <QPushButton>
 #include <QCheckBox>
+#include <QVBoxLayout>
+#include <QGridLayout>
 
 // other headers:
 #include <gpgme++/key.h>
@@ -370,8 +370,8 @@ namespace KMail {
 
     // "Sent-mail Folder" combo box and label:
     ++row;
-    mFccCombo = new FolderRequester( tab,
-        kmkernel->getKMMainWidget()->mainFolderView() );
+    mFccCombo = new FolderRequester( tab );
+    mFccCombo->setFolderTree( kmkernel->getKMMainWidget()->mainFolderView() );
     mFccCombo->setShowOutbox( false );
     glay->addWidget( mFccCombo, row, 1 );
     label = new QLabel( i18n("Sent-mail &folder:"), tab );
@@ -380,8 +380,8 @@ namespace KMail {
 
     // "Drafts Folder" combo box and label:
     ++row;
-    mDraftsCombo = new FolderRequester( tab,
-        kmkernel->getKMMainWidget()->mainFolderView() );
+    mDraftsCombo = new FolderRequester( tab );
+    mDraftsCombo->setFolderTree( kmkernel->getKMMainWidget()->mainFolderView() );
     mDraftsCombo->setShowOutbox( false );
     glay->addWidget( mDraftsCombo, row, 1 );
     label = new QLabel( i18n("&Drafts folder:"), tab );
@@ -390,8 +390,8 @@ namespace KMail {
 
     // "Templates Folder" combo box and label:
     ++row;
-    mTemplatesCombo = new FolderRequester( tab,
-        kmkernel->getKMMainWidget()->mainFolderView() );
+    mTemplatesCombo = new FolderRequester( tab );
+    mTemplatesCombo->setFolderTree( kmkernel->getKMMainWidget()->mainFolderView() );
     mTemplatesCombo->setShowOutbox( false );
     glay->addWidget( mTemplatesCombo, row, 1 );
     label = new QLabel( i18n("&Templates folder:"), tab );
@@ -422,7 +422,7 @@ namespace KMail {
     QHBoxLayout *tlay = new QHBoxLayout();
     vlay->addLayout( tlay );
 
-    mCustom = new QCheckBox( i18n("&Use custom message templates"), tab );
+    mCustom = new QCheckBox( i18n("&Use custom message templates for this identity"), tab );
     tlay->addWidget( mCustom, Qt::AlignLeft );
 
     mWidget = new TemplatesConfiguration( tab, "identity-templates" );
@@ -530,7 +530,7 @@ namespace KMail {
     QString brokenAddress;
 
     KPIMUtils::EmailParseResult errorCode =
-      KPIMUtils::isValidAddressList( KMMessage::expandAliases( addresses ),
+      KPIMUtils::isValidAddressList( StringUtil::expandAliases( addresses ),
                                      brokenAddress );
     if ( !( errorCode == KPIMUtils::AddressOk ||
             errorCode == KPIMUtils::AddressEmpty ) ) {
@@ -749,7 +749,7 @@ namespace KMail {
     uint identity = ident.uoid();
     QString iid = QString("IDENTITY_%1").arg( identity );
     Templates t( iid );
-    kDebug(5006) <<"use custom templates for identity" << identity <<":" << mCustom->isChecked();
+    kDebug() <<"use custom templates for identity" << identity <<":" << mCustom->isChecked();
     t.setUseCustomTemplates(mCustom->isChecked());
     t.writeConfig();
     mWidget->saveToIdentity( identity );
