@@ -55,6 +55,7 @@
 #include <kmessagebox.h>
 
 #include <QStringList>
+#include <QTextDocument>
 #include <time.h>
 
 #include <algorithm>
@@ -103,13 +104,13 @@ static bool ValidOpenPGPEncryptionKey( const GpgME::Key & key ) {
   }
 #if 0
   if ( key.isRevoked() )
-    kWarning(5006) <<" is revoked";
+    kWarning() <<" is revoked";
   if ( key.isExpired() )
-    kWarning(5006) <<" is expired";
+    kWarning() <<" is expired";
   if ( key.isDisabled() )
-    kWarning(5006) <<" is disabled";
+    kWarning() <<" is disabled";
   if ( !key.canEncrypt() )
-    kWarning(5006) <<" can't encrypt";
+    kWarning() <<" can't encrypt";
 #endif
   if ( key.isRevoked() || key.isExpired() || key.isDisabled() || !key.canEncrypt() )
     return false;
@@ -121,14 +122,14 @@ static bool ValidTrustedOpenPGPEncryptionKey( const GpgME::Key & key ) {
         return false;
   const std::vector<GpgME::UserID> uids = key.userIDs();
   for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin() ; it != uids.end() ; ++it ) {
-    if ( !it->isRevoked() && it->validity() > GpgME::UserID::Marginal )
+    if ( !it->isRevoked() && it->validity() >= GpgME::UserID::Marginal )
       return true;
 #if 0
     else
       if ( it->isRevoked() )
-        kWarning(5006) <<"a userid is revoked";
+        kWarning() <<"a userid is revoked";
       else
-        kWarning(5006) <<"bad validity" << it->validity();
+        kWarning() <<"bad validity" << it->validity();
 #endif
   }
   return false;
@@ -220,6 +221,42 @@ static inline bool NotValidSMIMESigningKey( const GpgME::Key & key ) {
   return !ValidSMIMESigningKey( key );
 }
 
+namespace {
+  struct ByTrustScore {
+    static int score( const GpgME::UserID & uid )
+    {
+      return uid.isRevoked() || uid.isInvalid() ? -1 : uid.validity() ;
+    }
+    bool operator()( const GpgME::UserID & lhs, const GpgME::UserID & rhs ) const
+    {
+      return score( lhs ) < score( rhs ) ;
+    }
+  };
+}
+
+static std::vector<GpgME::UserID> matchingUIDs( const std::vector<GpgME::UserID> & uids, const QString & address ) {
+    if ( address.isEmpty() )
+        return std::vector<GpgME::UserID>();
+
+    std::vector<GpgME::UserID> result;
+    result.reserve( uids.size() );
+    for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin(), end = uids.end() ; it != end ; ++it )
+        // PENDING(marc) check DN for an EMAIL, too, in case of X.509 certs... :/
+        if ( const char * email = it->email() )
+            if ( *email && QString::fromUtf8( email ).simplified().toLower() == address )
+                result.push_back( *it );
+    return result;
+}
+
+static GpgME::UserID findBestMatchUID( const GpgME::Key & key, const QString & address ) {
+    const std::vector<GpgME::UserID> all = key.userIDs();
+    if ( all.empty() )
+        return GpgME::UserID();
+    const std::vector<GpgME::UserID> matching = matchingUIDs( all, address.toLower() );
+    const std::vector<GpgME::UserID> & v = matching.empty() ? all : matching ;
+    return *std::max_element( v.begin(), v.end(), ByTrustScore() );
+}
+
 static QStringList keysAsStrings( const std::vector<GpgME::Key>& keys ) {
   QStringList strings;
   for ( std::vector<GpgME::Key>::const_iterator it = keys.begin() ; it != keys.end() ; ++it ) {
@@ -234,35 +271,40 @@ static QStringList keysAsStrings( const std::vector<GpgME::Key>& keys ) {
   return strings;
 }
 
-static inline std::vector<GpgME::Key> TrustedOrConfirmed( const std::vector<GpgME::Key> & keys ) {
+static std::vector<GpgME::Key> TrustedOrConfirmed( const std::vector<GpgME::Key> & keys, const QString & address ) {
 
+  // PENDING(marc) work on UserIDs here?
   std::vector<GpgME::Key> fishies;
   std::vector<GpgME::Key> ickies;
+  std::vector<GpgME::Key> rewookies;
   std::vector<GpgME::Key>::const_iterator it = keys.begin();
   const std::vector<GpgME::Key>::const_iterator end = keys.end();
   for ( ; it != end ; ++it ) {
-    const GpgME::Key key = *it;
+    const GpgME::Key & key = *it;
     assert( ValidEncryptionKey( key ) );
-    const std::vector<GpgME::UserID> uids = key.userIDs();
-    for ( std::vector<GpgME::UserID>::const_iterator it = uids.begin() ; it != uids.end() ; ++it ) {
-      if ( !it->isRevoked()  && it->validity() == GpgME::UserID::Marginal ) {
+    const GpgME::UserID uid = findBestMatchUID( key, address );
+    if ( uid.isRevoked() ) {
+        rewookies.push_back( key );
+    }
+    if ( !uid.isRevoked()  && uid.validity() == GpgME::UserID::Marginal ) {
         fishies.push_back( key );
-        break;
-      }
-      if ( !it->isRevoked()  && it->validity() < GpgME::UserID::Never ) {
+    }
+    if ( !uid.isRevoked()  && uid.validity() < GpgME::UserID::Never ) {
         ickies.push_back( key );
-        break;
-      }
     }
   }
 
-  if ( fishies.empty() && ickies.empty() )
+  if ( fishies.empty() && ickies.empty() && rewookies.empty() )
     return keys;
 
   // if  some keys are not fully trusted, let the user confirm their use
-  QString msg = i18n("One or more of your configured OpenPGP encryption "
-                      "keys or S/MIME certificates is not fully trusted "
-                      "for encryption.");
+  QString msg = address.isEmpty()
+      ? i18n("One or more of your configured OpenPGP encryption "
+             "keys or S/MIME certificates is not fully trusted "
+             "for encryption.")
+      : i18n("One or more of the OpenPGP encryption keys or S/MIME "
+             "certificates for recipient \"%1\" is not fully trusted "
+             "for encryption.", address) ;
 
   if ( !fishies.empty() ) {
     // certificates can't have marginal trust
@@ -273,6 +315,10 @@ static inline std::vector<GpgME::Key> TrustedOrConfirmed( const std::vector<GpgM
     msg += i18n( "\nThe following keys or certificates have unknown trust level: \n");
     msg += keysAsStrings( ickies ).join(",");
   }
+  if ( !rewookies.empty() ) {
+    msg += i18n( "\nThe following keys or certificates are <b>revoked</b>: \n");
+    msg += keysAsStrings( rewookies ).join(",");
+  }
 
   if( KMessageBox::warningContinueCancel( 0, msg, i18n("Not Fully Trusted Encryption Keys"),
                                           KStandardGuiItem::cont(), KStandardGuiItem::cancel(),
@@ -363,6 +409,11 @@ public:
   }
   void operator()( Item & item );
 
+  template <typename Container>
+  void process( Container & c ) {
+    *this = std::for_each( c.begin(), c.end(), *this );
+  }
+
 #define make_int_accessor(x) unsigned int num##x() const { return m##x; }
   make_int_accessor(NoKey)
   make_int_accessor(NeverEncrypt)
@@ -375,6 +426,7 @@ public:
 #undef make_int_accessor
 private:
   EncryptionPreference mDefaultPreference;
+  bool mNoOps;
   unsigned int mTotal;
   unsigned int mNoKey;
   unsigned int mNeverEncrypt, mUnknownPreference, mAlwaysEncrypt,
@@ -382,12 +434,14 @@ private:
 };
 
 void Kleo::KeyResolver::EncryptionPreferenceCounter::operator()( Item & item ) {
+  if ( _this ) {
   if ( item.needKeys )
     item.keys = _this->getEncryptionKeys( item.address, true );
   if ( item.keys.empty() ) {
     ++mNoKey;
     return;
   }
+  }
   switch ( !item.pref ? mDefaultPreference : item.pref ) {
 #define CASE(x) case Kleo::x: ++m##x; break
     CASE(NeverEncrypt);
@@ -545,20 +599,112 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
                                                     int recur_limit, const GpgME::Key & orig ) const
 {
   if ( recur_limit <= 0 ) {
-    kDebug(5006) << "Key chain too long (>100 certs)";
+    kDebug() << "Key chain too long (>100 certs)";
     return Kpgp::Ok;
   }
   const GpgME::Subkey subkey = key.subkey(0);
   if ( d->alreadyWarnedFingerprints.count( subkey.fingerprint() ) )
     return Kpgp::Ok; // already warned about this one (and so about it's issuers)
-  d->alreadyWarnedFingerprints.insert( subkey.fingerprint() );
 
   if ( subkey.neverExpires() )
     return Kpgp::Ok;
   static const double secsPerDay = 24 * 60 * 60;
-  const int daysTillExpiry =
-    1 + int( ::difftime( subkey.expirationTime(), time(0) ) / secsPerDay );
-  kDebug(5006) <<"Key 0x" << key.shortKeyID() <<"expires in less than"
+  const double secsTillExpiry = ::difftime( subkey.expirationTime(), time(0) );
+  if ( secsTillExpiry <= 0 ) {
+      const int daysSinceExpiry = 1 + int( -secsTillExpiry / secsPerDay );
+      kDebug() << "Key 0x" << key.shortKeyID() << " expired less than "
+                   << daysSinceExpiry << " days ago";
+      const QString msg =
+          key.protocol() == GpgME::OpenPGP
+          ? ( mine ? sign
+              ? ki18np("<p>Your OpenPGP signing key</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired less than a day ago.</p>",
+                       "<p>Your OpenPGP signing key</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired %1 days ago.</p>")
+              : ki18np("<p>Your OpenPGP encryption key</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired less than a day ago.</p>",
+                       "<p>Your OpenPGP encryption key</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired %1 days ago.</p>")
+              : ki18np("<p>The OpenPGP key for</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired less than a day ago.</p>",
+                       "<p>The OpenPGP key for</p><p align=center><b>%2</b> (KeyID 0x%3)</p>"
+                       "<p>expired %1 days ago.</p>") )
+		  .subs( daysSinceExpiry )
+		  .subs( QString::fromUtf8( key.userID(0).id() ) )
+		  .subs( key.shortKeyID() )
+		  .toString()
+          : ( ca
+              ? ( key.isRoot()
+                  ? ( mine ? sign
+                      ? ki18np("<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>")
+                      : ki18np("<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>")
+                      : ki18np("<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for S/MIME certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The root certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for S/MIME certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>") )
+                  : ( mine ? sign
+                      ? ki18np("<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>")
+                      : ki18np("<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>")
+                      : ki18np("<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for S/MIME certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired less than a day ago.</p>",
+                               "<p>The intermediate CA certificate</p><p align=center><b>%4</b></p>"
+                               "<p>for S/MIME certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                               "<p>expired %1 days ago.</p>") ) )
+			   .subs( daysSinceExpiry )
+			   .subs( Kleo::DN( orig.userID(0).id() ).prettyDN() )
+			   .subs( orig.issuerSerial() )
+			   .subs( Kleo::DN( key.userID(0).id() ).prettyDN() )
+			   .toString()
+              : ( mine ? sign
+                  ? ki18np("<p>Your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired less than a day ago.</p>",
+                           "<p>Your S/MIME signing certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired %1 days ago.</p>")
+                  : ki18np("<p>Your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired less than a day ago.</p>",
+                           "<p>Your S/MIME encryption certificate</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired %1 days ago.</p>")
+                  : ki18np("<p>The S/MIME certificate for</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired less than a day ago.</p>",
+                           "<p>The S/MIME certificate for</p><p align=center><b>%2</b> (serial number %3)</p>"
+                           "<p>expired %1 days ago.</p>" ) )
+		       .subs( daysSinceExpiry )
+		       .subs( Kleo::DN( key.userID(0).id() ).prettyDN() )
+		       .subs( key.issuerSerial() )
+		       .toString() );
+      d->alreadyWarnedFingerprints.insert( subkey.fingerprint() );
+      if ( KMessageBox::warningContinueCancel( 0, msg,
+                                               key.protocol() == GpgME::OpenPGP
+                                               ? i18n("OpenPGP Key Expired" )
+                                               : i18n("S/MIME Certificate Expired" ),
+                                               KStandardGuiItem::cont(), KStandardGuiItem::cancel(), dontAskAgainName ) == KMessageBox::Cancel )
+          return Kpgp::Canceled;
+  } else {
+  const int daysTillExpiry = 1 + int( secsTillExpiry / secsPerDay );
+  kDebug() <<"Key 0x" << key.shortKeyID() <<"expires in less than"
 	           << daysTillExpiry << "days";
   const int threshold =
     ca
@@ -654,6 +800,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 		       .subs( Kleo::DN( key.userID(0).id() ).prettyDN() )
 		       .subs( key.issuerSerial() )
 		       .toString() );
+    d->alreadyWarnedFingerprints.insert( subkey.fingerprint() );
     if ( KMessageBox::warningContinueCancel( 0, msg,
 					     key.protocol() == GpgME::OpenPGP
 					     ? i18n("OpenPGP Key Expires Soon" )
@@ -663,6 +810,7 @@ Kpgp::Result Kleo::KeyResolver::checkKeyNearExpiry( const GpgME::Key & key, cons
 	 == KMessageBox::Cancel )
       return Kpgp::Canceled;
   }
+  }
   if ( key.isRoot() )
     return Kpgp::Ok;
   else if ( const char * chain_id = key.chainID() ) {
@@ -840,6 +988,20 @@ Kleo::Action Kleo::KeyResolver::checkEncryptionPreferences( bool encryptionReque
        d->mOpenPGPEncryptToSelfKeys.empty() && d->mSMIMEEncryptToSelfKeys.empty() )
     return Impossible;
 
+  if ( !encryptionRequested && !mOpportunisticEncyption ) {
+    // try to minimize crypto ops (including key lookups) by only
+    // looking up keys when at least one the the encryption
+    // preferences needs it:
+    EncryptionPreferenceCounter count( 0, UnknownPreference );
+    count.process( d->mPrimaryEncryptionKeys );
+    count.process( d->mSecondaryEncryptionKeys );
+    if ( !count.numAlwaysEncrypt() &&
+         !count.numAlwaysAskForEncryption() && // this guy might not need a lookup, when declined, but it's too complex to implement that here
+         !count.numAlwaysEncryptIfPossible() &&
+         !count.numAskWheneverPossible() )
+        return DontDoIt;
+  }
+
   EncryptionPreferenceCounter count( this, mOpportunisticEncyption ? AskWheneverPossible : UnknownPreference );
   count = std::for_each( d->mPrimaryEncryptionKeys.begin(), d->mPrimaryEncryptionKeys.end(),
 			 count );
@@ -885,9 +1047,10 @@ Kpgp::Result Kleo::KeyResolver::resolveAllKeys( bool& signingRequested, bool& en
     result = resolveEncryptionKeys( signingRequested );
   if ( result != Kpgp::Ok )
     return result;
-  if ( signingRequested )
-    if ( encryptionRequested )
+  if ( signingRequested ) {
+    if ( encryptionRequested ) {
       result = resolveSigningKeysForEncryption();
+    }
     else {
       result = resolveSigningKeysForSigningOnly();
       if ( result == Kpgp::Failure ) {
@@ -895,6 +1058,7 @@ Kpgp::Result Kleo::KeyResolver::resolveAllKeys( bool& signingRequested, bool& en
         return Kpgp::Ok;
       }
     }
+  }
   return result;
 }
 
@@ -1392,9 +1556,14 @@ std::vector<GpgME::Key> Kleo::KeyResolver::signingKeys( CryptoMessageFormat f )
 
 
 std::vector<GpgME::Key> Kleo::KeyResolver::selectKeys( const QString & person, const QString & msg, const std::vector<GpgME::Key> & selectedKeys ) const {
+  const bool opgp = containsOpenPGP( mCryptoMessageFormats );
+  const bool x509 = containsSMIME( mCryptoMessageFormats );
+
   Kleo::KeySelectionDialog dlg( i18n("Encryption Key Selection"),
 				msg, selectedKeys,
-				Kleo::KeySelectionDialog::ValidEncryptionKeys,
+                                Kleo::KeySelectionDialog::ValidEncryptionKeys
+                                & ~(opgp ? 0 : Kleo::KeySelectionDialog::OpenPGPKeys)
+                                & ~(x509 ? 0 : Kleo::KeySelectionDialog::SMIMEKeys),
 				true, true ); // multi-selection and "remember choice" box
 
   if ( dlg.exec() != QDialog::Accepted )
@@ -1417,7 +1586,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
   const QStringList fingerprints = keysForAddress( address );
 
   if ( !fingerprints.empty() ) {
-    kDebug(5006) <<"Using encryption keys 0x"
+    kDebug() <<"Using encryption keys 0x"
 	             << fingerprints.join( ", 0x" )
 	             << "for" << person;
     std::vector<GpgME::Key> keys = lookup( fingerprints );
@@ -1438,7 +1607,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
               "be used for this recipient.", person),
             keys );
       }
-      keys = TrustedOrConfirmed( keys );
+      keys = TrustedOrConfirmed( keys, address );
 
       if ( !keys.empty() )
         return keys;
@@ -1463,7 +1632,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
   // check if there are keys for this recipients, not (yet) their validity, so
   // don't show the untrusted encryption key warning in that case
   if ( !quiet )
-    matchingKeys = TrustedOrConfirmed( matchingKeys );
+    matchingKeys = TrustedOrConfirmed( matchingKeys, address );
   if ( quiet || matchingKeys.size() == 1 )
     return matchingKeys;
 
@@ -1475,24 +1644,27 @@ std::vector<GpgME::Key> Kleo::KeyResolver::getEncryptionKeys( const QString & pe
           ? i18nc("if in your language something like "
               "'key(s)' is not possible please "
               "use the plural in the translation",
-              "No valid and trusted encryption key was "
-              "found for \"%1\".\n\n"
+              "<qt>No valid and trusted encryption key was "
+              "found for \"%1\".<br/><br/>"
               "Select the key(s) which should "
-              "be used for this recipient.", person)
+              "be used for this recipient. If there is no suitable key in the list "
+              "you can also <a href=\"%2\">search for external keys</a>.</qt>",
+              Qt::escape( person ),
+              QLatin1String( QUrl::toPercentEncoding( KPIMUtils::extractEmailAddress( person) ) ) )
           : i18nc("if in your language something like "
               "'key(s)' is not possible please "
               "use the plural in the translation",
               "More than one key matches \"%1\".\n\n"
               "Select the key(s) which should "
               "be used for this recipient.", person),
-          matchingKeys ) );
+          matchingKeys ), address );
 }
 
 
 std::vector<GpgME::Key> Kleo::KeyResolver::lookup( const QStringList & patterns, bool secret ) const {
   if ( patterns.empty() )
     return std::vector<GpgME::Key>();
-  kDebug(5006) << "( \"" << patterns.join("\", \"" ) << "\"," << secret << ")";
+  kDebug() << "( \"" << patterns.join("\", \"" ) << "\"," << secret << ")";
   std::vector<GpgME::Key> result;
   if ( mCryptoMessageFormats & (InlineOpenPGPFormat|OpenPGPMIMEFormat) )
     if ( const Kleo::CryptoBackend::Protocol * p = Kleo::CryptoBackendFactory::instance()->openpgp() ) {
@@ -1512,7 +1684,7 @@ std::vector<GpgME::Key> Kleo::KeyResolver::lookup( const QStringList & patterns,
 	result.insert( result.end(), keys.begin(), keys.end() );
       }
     }
-  kDebug(5006) <<"  returned" << result.size() <<" keys";
+  kDebug() <<"  returned" << result.size() <<" keys";
   return result;
 }
 
@@ -1544,7 +1716,7 @@ void Kleo::KeyResolver::addKeys( const std::vector<Item> & items ) {
       }
     }
     if ( f == AutoFormat )
-      kWarning(5006) << "Something went wrong. Didn't find a format for \""
+      kWarning() << "Something went wrong. Didn't find a format for \""
                   << it->address << "\"";
     else
       std::remove_copy_if( it->keys.begin(), it->keys.end(),
@@ -1589,7 +1761,7 @@ void Kleo::KeyResolver::saveContactPreference( const QString& email, const Conta
   KABC::Addressee addr;
   if ( res.isEmpty() ) {
      bool ok = true;
-     QString fullName = KInputDialog::getText( i18n( "Name Selection" ), i18n( "Which name shall the contact '%1' have in your addressbook?", email ), QString(), &ok );
+     QString fullName = KInputDialog::getText( i18n( "Name Selection" ), i18n( "Which name shall the contact '%1' have in your address book?", email ), QString(), &ok );
     if ( ok ) {
       addr.setNameFromString( fullName );
       addr.insertEmail( email, true );
