@@ -37,7 +37,7 @@ void KabcBridge::addresses(QStringList& result) // includes lists
 
   KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
   KABC::AddressBook::ConstIterator it;
-  for( it = addressBook->begin(); it != addressBook->end(); ++it ) {
+  for( it = addressBook->constBegin(); it != addressBook->constEnd(); ++it ) {
     const QStringList emails = (*it).emails();
     QString n = (*it).prefix() + ' ' +
                 (*it).givenName() + ' ' +
@@ -120,8 +120,8 @@ QStringList KabcBridge::categories()
   for ( KABC::Addressee::List::Iterator it = addresses.begin();
         it != addresses.end(); ++it ) {
     aux = ( *it ).categories();
-    for ( QStringList::ConstIterator itAux = aux.begin();
-          itAux != aux.end(); ++itAux ) {
+    for ( QStringList::ConstIterator itAux = aux.constBegin();
+          itAux != aux.constEnd(); ++itAux ) {
       // don't have duplicates in allcategories
       if ( !allcategories.contains( *itAux )  )
         allcategories += *itAux;
