@@ -23,6 +23,8 @@
 #define kmkernel KMKernel::self()
 #define kmconfig KMKernel::config()
 
+Q_DECLARE_METATYPE(QVector<QStringList>)
+
 namespace KIO {
   class Job;
 }
@@ -37,6 +39,7 @@ class KJob;
 */
 namespace KMail {
   class MailServiceImpl;
+  class MailManagerImpl;
   class UndoStack;
   class JobScheduler;
   class MessageSender;
@@ -45,6 +48,7 @@ namespace KMail {
 }
 namespace KPIM { class ProgressDialog; }
 using KMail::MailServiceImpl;
+using KMail::MailManagerImpl;
 using KMail::AccountManager;
 using KMail::UndoStack;
 using KMail::JobScheduler;
@@ -496,6 +500,7 @@ private:
   // temporary mainwin
   KMMainWin *mWin;
   MailServiceImpl *mMailService;
+  MailManagerImpl *mMailManager;
 
   // the time of the last change of the unread or total count of a folder;
   // this can be queried via D-Bus in order to determine whether the counts
