@@ -1,9 +1,10 @@
 /* kmail message dictionary */
 /* Author: Ronen Tzur <rtzur@shani.net> */
 
+#include "kmmsgdict.h"
+
 #include "kmfolderindex.h"
 #include "kmfolder.h"
-#include "kmmsgdict.h"
 #include "kmdict.h"
 #include "globalsettings.h"
 #include "folderstorage.h"
@@ -219,9 +220,9 @@ unsigned long KMMsgDict::insert(unsigned long msgSerNum,
 
   KMFolderIndex* folder = static_cast<KMFolderIndex*>( msg->storage() );
   if ( !folder ) {
-    kDebug(5006) << "Cannot insert the message,"
+    kDebug() << "Cannot insert the message,"
       << "null pointer to storage. Requested serial: " << msgSerNum;
-    kDebug(5006) <<"  Message info: Subject:" << msg->subject() <<", To:"
+    kDebug() <<"  Message info: Subject:" << msg->subject() <<", To:"
       << msg->toStrip() << ", Date:" << msg->dateStr();
     return 0;
   }
@@ -262,9 +263,9 @@ void KMMsgDict::replace(unsigned long msgSerNum,
 {
   KMFolderIndex* folder = static_cast<KMFolderIndex*>( msg->storage() );
   if ( !folder ) {
-    kDebug(5006) << "Cannot replace the message serial"
+    kDebug() << "Cannot replace the message serial"
       << "number, null pointer to storage. Requested serial: " << msgSerNum;
-    kDebug(5006) <<"  Message info: Subject:" << msg->subject() <<", To:"
+    kDebug() <<"  Message info: Subject:" << msg->subject() <<", To:"
       << msg->toStrip() << ", Date:" << msg->dateStr();
     return;
   }
@@ -530,11 +531,10 @@ KMMsgDictREntry *KMMsgDict::openFolderIds( const FolderStorage& storage, bool tr
       fp = KDE_fopen(QFile::encodeName(filename), "w+");
       if (!fp)
       {
-        kDebug(5006) <<"Dict '" << filename
+        kDebug() <<"Dict '" << filename
                       << "' cannot open with folder" << storage.label() << ":"
                       << strerror(errno) << "(" << errno << ")";
-         delete rentry;
-         rentry = 0;
+         storage.setRDict(0);
          return 0;
       }
       fprintf(fp, IDS_HEADER, IDS_VERSION);
@@ -559,10 +559,10 @@ int KMMsgDict::writeFolderIds( const FolderStorage &storage )
   FILE *fp = rentry->fp;
 
   KDE_fseek( fp, rentry->baseOffset, SEEK_SET );
-  // kDebug(5006) <<"Dict writing for folder" << storage.label();
+  // kDebug() <<"Dict writing for folder" << storage.label();
   quint32 count = rentry->getRealSize();
   if (!fwrite(&count, sizeof(count), 1, fp)) {
-    kDebug(5006) <<"Dict cannot write count with folder" << storage.label() <<":"
+    kDebug() <<"Dict cannot write count with folder" << storage.label() <<":"
                   << strerror(errno) << "(" << errno << ")";
     return -1;
   }
@@ -613,12 +613,12 @@ int KMMsgDict::appendToFolderIds( FolderStorage& storage, int index)
     return 0;
   FILE *fp = rentry->fp;
 
-//  kDebug(5006) <<"Dict appending for folder" << storage.label();
+//  kDebug() <<"Dict appending for folder" << storage.label();
 
   KDE_fseek( fp, rentry->baseOffset, SEEK_SET );
   quint32 count;
   if (!fread(&count, sizeof(count), 1, fp)) {
-    kDebug(5006) <<"Dict cannot read count for folder" << storage.label() <<":"
+    kDebug() <<"Dict cannot read count for folder" << storage.label() <<":"
                   << strerror(errno) << "(" << errno << ")";
     return 0;
   }
@@ -631,7 +631,7 @@ int KMMsgDict::appendToFolderIds( FolderStorage& storage, int index)
      count = kmail_swap_32(count);
   KDE_fseek( fp, rentry->baseOffset, SEEK_SET );
   if (!fwrite(&count, sizeof(count), 1, fp)) {
-    kDebug(5006) <<"Dict cannot write count for folder" << storage.label() <<":"
+    kDebug() <<"Dict cannot write count for folder" << storage.label() <<":"
                   << strerror(errno) << "(" << errno << ")";
     return 0;
   }
@@ -645,7 +645,7 @@ int KMMsgDict::appendToFolderIds( FolderStorage& storage, int index)
   if (rentry->swapByteOrder)
      msn = kmail_swap_32(msn);
   if (!fwrite(&msn, sizeof(msn), 1, fp)) {
-    kDebug(5006) <<"Dict cannot write count for folder" << storage.label() <<":"
+    kDebug() <<"Dict cannot write count for folder" << storage.label() <<":"
                   << strerror(errno) << "(" << errno << ")";
     return 0;
   }
