@@ -28,16 +28,14 @@
 #ifndef LISTJOB_H
 #define LISTJOB_H
 
+#include <kio/udsentry.h>
+
 #include "folderjob.h"
 #include "imapaccountbase.h"
 
-class KMFolderImap;
-class KMFolderCachedImap;
-class KMAcctImap;
-class KMAcctCachedImap;
 class FolderStorage;
-class KURL;
-
+class KUrl;
+class KJob; 
 namespace KIO {
   class Job;
 }
@@ -66,7 +64,7 @@ public:
    * @param item a parent ProgressItem
    */
   ListJob( ImapAccountBase* account, ImapAccountBase::ListType type,
-           FolderStorage* storage = 0, const QString& path = QString::null,
+           FolderStorage* storage = 0, const QString& path = QString(),
            bool complete = false, KPIM::ProgressItem* item = 0 );
 
   virtual ~ListJob();
@@ -108,7 +106,7 @@ protected slots:
    * Is called when the listing is done
    * Passes the folders and the jobData to the responding folder
    */
-  void slotListResult( KIO::Job* job );
+  void slotListResult( KJob* job );
 
   /**
    * Collects the folder information
