@@ -1,42 +1,41 @@
 // -*- Mode: C++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 #include "mailinglist-magic.h"
 
 #include "kmmessage.h"
 
 #include <kconfig.h>
+#include <kconfiggroup.h>
 #include <kurl.h>
 #include <kdebug.h>
 
-#include <qstringlist.h>
+#include <QStringList>
+#include <QByteArray>
 
 using namespace KMail;
 
-typedef QString (*MagicDetectorFunc) (const KMMessage *, QCString &, QString &);
+typedef QString (*MagicDetectorFunc) (const KMMessage *, QByteArray &, QString &);
 
 /* Sender: (owner-([^@]+)|([^@+]-owner)@ */
 static QString check_sender(const KMMessage  *message,
-                            QCString &header_name,
+                            QByteArray &header_name,
                             QString &header_value )
 {
   QString header = message->headerField( "Sender" );
 
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
   if ( header.left( 6 ) == "owner-" )
   {
     header_name = "Sender";
     header_value = header;
-    header = header.mid( 6, header.find( '@' ) - 6 );
+    header = header.mid( 6, header.indexOf( '@' ) - 6 );
 
   } else {
-    int index = header.find( "-owner@ " );
+    int index = header.indexOf( "-owner@ " );
     if ( index == -1 )
-      return QString::null;
+      return QString();
 
     header.truncate( index );
     header_name = "Sender";
@@ -48,73 +47,73 @@ static QString check_sender(const KMMessage  *message,
 
 /* X-BeenThere: ([^@]+) */
 static QString check_x_beenthere(const KMMessage  *message,
-                                 QCString &header_name,
+                                 QByteArray &header_name,
                                  QString &header_value )
 {
   QString header = message->headerField( "X-BeenThere" );
-  if ( header.isNull() || header.find( '@' ) == -1 )
-    return QString::null;
+  if ( header.isNull() || header.indexOf( '@' ) == -1 )
+    return QString();
 
   header_name = "X-BeenThere";
   header_value = header;
-  header.truncate( header.find( '@' ) );
+  header.truncate( header.indexOf( '@' ) );
   return header;
 }
 
 /* Delivered-To:: <([^@]+) */
 static QString check_delivered_to(const KMMessage  *message,
-                                  QCString &header_name,
+                                  QByteArray &header_name,
                                   QString &header_value )
 {
   QString header = message->headerField( "Delivered-To" );
   if ( header.isNull() || header.left(13 ) != "mailing list"
-       || header.find( '@' ) == -1 )
-    return QString::null;
+       || header.indexOf( '@' ) == -1 )
+    return QString();
 
   header_name = "Delivered-To";
   header_value = header;
 
-  return header.mid( 13, header.find( '@' ) - 13 );
+  return header.mid( 13, header.indexOf( '@' ) - 13 );
 }
 
 /* X-Mailing-List: <?([^@]+) */
 static QString check_x_mailing_list(const KMMessage  *message,
-                                    QCString &header_name,
+                                    QByteArray &header_name,
                                     QString &header_value )
 {
   QString header = message->headerField( "X-Mailing-List");
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
-  if ( header.find( '@' ) < 1 )
-    return QString::null;
+  if ( header.indexOf( '@' ) < 1 )
+    return QString();
 
   header_name = "X-Mailing-List";
   header_value = header;
   if ( header[0] == '<' )
-    header = header.mid(1,  header.find( '@' ) - 1);
+    header = header.mid(1,  header.indexOf( '@' ) - 1);
   else
-    header.truncate( header.find( '@' ) );
+    header.truncate( header.indexOf( '@' ) );
   return header;
 }
 
 /* List-Id: [^<]* <([^.]+) */
 static QString check_list_id(const KMMessage  *message,
-			     QCString &header_name,
+			     QByteArray &header_name,
 			     QString &header_value )
 {
   int lAnglePos, firstDotPos;
   QString header = message->headerField( "List-Id" );
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
-  lAnglePos = header.find( '<' );
+  lAnglePos = header.indexOf( '<' );
   if ( lAnglePos < 0 )
-    return QString::null;
+    return QString();
 
-  firstDotPos = header.find( '.', lAnglePos );
+  firstDotPos = header.indexOf( '.', lAnglePos );
   if ( firstDotPos < 0 )
-    return QString::null;
+    return QString();
 
   header_name = "List-Id";
   header_value = header.mid( lAnglePos );
@@ -125,71 +124,71 @@ static QString check_list_id(const KMMessage  *message,
 
 /* List-Post: <mailto:[^< ]*>) */
 static QString check_list_post(const KMMessage  *message,
-                               QCString &header_name,
+                               QByteArray &header_name,
                                QString &header_value )
 {
   QString header = message->headerField( "List-Post" );
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
-  int lAnglePos = header.find( "<mailto:" );
+  int lAnglePos = header.indexOf( "<mailto:" );
   if ( lAnglePos < 0 )
-    return QString::null;
+    return QString();
 
   header_name = "List-Post";
   header_value = header;
   header = header.mid( lAnglePos + 8, header.length());
-  header.truncate( header.find('@') );
+  header.truncate( header.indexOf('@') );
   return header;
 }
 
 /* Mailing-List: list ([^@]+) */
 static QString check_mailing_list(const KMMessage  *message,
-                                  QCString &header_name,
+                                  QByteArray &header_name,
                                   QString &header_value )
 {
   QString header = message->headerField( "Mailing-List");
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
-  if (header.left( 5 ) != "list " || header.find( '@' ) < 5 )
-    return QString::null;
+  if (header.left( 5 ) != "list " || header.indexOf( '@' ) < 5 )
+    return QString();
 
   header_name = "Mailing-List";
   header_value = header;
-  header = header.mid(5,  header.find( '@' ) - 5);
+  header = header.mid(5,  header.indexOf( '@' ) - 5);
   return header;
 }
 
 
 /* X-Loop: ([^@]+) */
 static QString check_x_loop(const KMMessage  *message,
-                            QCString &header_name,
+                            QByteArray &header_name,
                             QString &header_value ){
   QString header = message->headerField( "X-Loop");
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
-  if (header.find( '@' ) < 2 )
-    return QString::null;
+  if (header.indexOf( '@' ) < 2 )
+    return QString();
 
   header_name = "X-Loop";
   header_value = header;
-  header.truncate(header.find( '@' ));
+  header.truncate(header.indexOf( '@' ));
   return header;
 }
 
 /* X-ML-Name: (.+) */
 static QString check_x_ml_name(const KMMessage  *message,
-                               QCString &header_name,
+                               QByteArray &header_name,
                                QString &header_value ){
   QString header = message->headerField( "X-ML-Name");
   if ( header.isEmpty() )
-    return QString::null;
+    return QString();
 
   header_name = "X-ML-Name";
   header_value = header;
-  header.truncate(header.find( '@' ));
+  header.truncate(header.indexOf( '@' ));
   return header;
 }
 
@@ -218,12 +217,12 @@ headerToAddress( const QString& header )
   if ( header.isEmpty() )
     return addr;
 
-  while ( (start = header.find( "<", start )) != -1 ) {
-    if ( (end = header.find( ">", ++start ) ) == -1 ) {
-      kdDebug(5006)<<k_funcinfo<<"Serious mailing list header parsing error !"<<endl;
+  while ( (start = header.indexOf( "<", start )) != -1 ) {
+    if ( (end = header.indexOf( ">", ++start ) ) == -1 ) {
+      kDebug()<<"Serious mailing list header parsing error !";
       return addr;
     }
-    kdDebug(5006)<<"Mailing list = "<<header.mid( start, end - start )<<endl;
+    kDebug()<<"Mailing list ="<<header.mid( start, end - start );
     addr.append( header.mid( start, end - start ) );
   }
   return  addr;
@@ -250,15 +249,15 @@ MailingList::detect( const KMMessage *message )
 }
 
 QString
-MailingList::name( const KMMessage  *message, QCString &header_name,
+MailingList::name( const KMMessage  *message, QByteArray &header_name,
                    QString &header_value )
 {
   QString mlist;
-  header_name = QCString();
-  header_value = QString::null;
+  header_name = QByteArray();
+  header_value.clear();
 
   if ( !message )
-    return QString::null;
+    return QString();
 
   for (int i = 0; i < num_detectors; i++) {
     mlist = magic_detector[i] (message, header_name, header_value);
@@ -266,7 +265,7 @@ MailingList::name( const KMMessage  *message, QCString &header_name,
       return mlist;
   }
 
-  return QString::null;
+  return QString();
 }
 
 MailingList::MailingList()
@@ -292,7 +291,7 @@ MailingList::handler() const
 }
 
 void
-MailingList::setPostURLS ( const KURL::List& lst )
+MailingList::setPostURLS ( const KUrl::List& lst )
 {
   mFeatures |= Post;
   if ( lst.empty() ) {
@@ -300,14 +299,14 @@ MailingList::setPostURLS ( const KURL::List& lst )
   }
   mPostURLS = lst;
 }
-KURL::List
+KUrl::List
 MailingList::postURLS() const
 {
   return mPostURLS;
 }
 
 void
-MailingList::setSubscribeURLS( const KURL::List& lst )
+MailingList::setSubscribeURLS( const KUrl::List& lst )
 {
   mFeatures |= Subscribe;
   if ( lst.empty() ) {
@@ -316,14 +315,14 @@ MailingList::setSubscribeURLS( const KURL::List& lst )
 
   mSubscribeURLS = lst;
 }
-KURL::List
+KUrl::List
 MailingList::subscribeURLS() const
 {
   return mSubscribeURLS;
 }
 
 void
-MailingList::setUnsubscribeURLS( const KURL::List& lst )
+MailingList::setUnsubscribeURLS( const KUrl::List& lst )
 {
   mFeatures |= Unsubscribe;
   if ( lst.empty() ) {
@@ -332,13 +331,13 @@ MailingList::setUnsubscribeURLS( const KURL::List& lst )
 
   mUnsubscribeURLS = lst;
 }
-KURL::List MailingList::unsubscribeURLS() const
+KUrl::List MailingList::unsubscribeURLS() const
 {
   return mUnsubscribeURLS;
 }
 
 void
-MailingList::setHelpURLS( const KURL::List& lst )
+MailingList::setHelpURLS( const KUrl::List& lst )
 {
   mFeatures |= Help;
   if ( lst.empty() ) {
@@ -347,14 +346,14 @@ MailingList::setHelpURLS( const KURL::List& lst )
 
   mHelpURLS = lst;
 }
-KURL::List
+KUrl::List
 MailingList::helpURLS() const
 {
   return mHelpURLS;
 }
 
 void
-MailingList::setArchiveURLS( const KURL::List& lst )
+MailingList::setArchiveURLS( const KUrl::List& lst )
 {
   mFeatures |= Archive;
   if ( lst.empty() ) {
@@ -363,7 +362,7 @@ MailingList::setArchiveURLS( const KURL::List& lst )
 
   mArchiveURLS = lst;
 }
-KURL::List
+KUrl::List
 MailingList::archiveURLS() const
 {
   return mArchiveURLS;
@@ -386,29 +385,29 @@ MailingList::id() const
 }
 
 void
-MailingList::writeConfig( KConfig* config ) const
+MailingList::writeConfig( KConfigGroup & config ) const
 {
-  config->writeEntry( "MailingListFeatures", mFeatures );
-  config->writeEntry( "MailingListHandler", mHandler );
-  config->writeEntry( "MailingListId",  mId );
-  config->writeEntry( "MailingListPostingAddress", mPostURLS.toStringList() );
-  config->writeEntry( "MailingListSubscribeAddress", mSubscribeURLS.toStringList() );
-  config->writeEntry( "MailingListUnsubscribeAddress", mUnsubscribeURLS.toStringList() );
-  config->writeEntry( "MailingListArchiveAddress", mArchiveURLS.toStringList() );
-  config->writeEntry( "MailingListHelpAddress", mHelpURLS.toStringList() );
+  config.writeEntry( "MailingListFeatures", mFeatures );
+  config.writeEntry( "MailingListHandler", (int)mHandler );
+  config.writeEntry( "MailingListId",  mId );
+  config.writeEntry( "MailingListPostingAddress", mPostURLS.toStringList() );
+  config.writeEntry( "MailingListSubscribeAddress", mSubscribeURLS.toStringList() );
+  config.writeEntry( "MailingListUnsubscribeAddress", mUnsubscribeURLS.toStringList() );
+  config.writeEntry( "MailingListArchiveAddress", mArchiveURLS.toStringList() );
+  config.writeEntry( "MailingListHelpAddress", mHelpURLS.toStringList() );
 }
 
 void
-MailingList::readConfig( KConfig* config )
+MailingList::readConfig( KConfigGroup & config )
 {
-  mFeatures =  config->readNumEntry( "MailingListFeatures", 0 );
+  mFeatures =  config.readEntry( "MailingListFeatures", 0 );
   mHandler = static_cast<MailingList::Handler>(
-    config->readNumEntry( "MailingListHandler", MailingList::KMail ) );
+    config.readEntry( "MailingListHandler", (int)MailingList::KMail ) );
 
-  mId = config->readEntry("MailingListId");
-  mPostURLS        = config->readListEntry( "MailingListPostingAddress" );
-  mSubscribeURLS   = config->readListEntry( "MailingListSubscribeAddress" );
-  mUnsubscribeURLS = config->readListEntry( "MailingListUnsubscribeAddress" );
-  mArchiveURLS     = config->readListEntry( "MailingListArchiveAddress" );
-  mHelpURLS        = config->readListEntry( "MailingListHelpAddress" );
+  mId = config.readEntry("MailingListId");
+  mPostURLS        = config.readEntry( "MailingListPostingAddress", QStringList() );
+  mSubscribeURLS   = config.readEntry( "MailingListSubscribeAddress", QStringList() );
+  mUnsubscribeURLS = config.readEntry( "MailingListUnsubscribeAddress", QStringList() );
+  mArchiveURLS     = config.readEntry( "MailingListArchiveAddress", QStringList() );
+  mHelpURLS        = config.readEntry( "MailingListHelpAddress", QStringList() );
 }
