@@ -13,7 +13,6 @@
 
 #include "snippetdlg.h"
 
-#include <kdeversion.h>
 #include <kdialog.h>
 #include <klocale.h>
 
@@ -30,6 +29,7 @@
  *  The dialog will by default be modeless, unless you set 'modal' to
  *  TRUE to construct a modal dialog.
  */
+//Laurent: don't use a KDialog here not necessary and create a layout warning
 SnippetDlg::SnippetDlg( KActionCollection* ac, QWidget* parent, bool modal,
                         Qt::WindowFlags f )
   : QDialog( parent, f ),
@@ -39,11 +39,6 @@ SnippetDlg::SnippetDlg( KActionCollection* ac, QWidget* parent, bool modal,
     setModal( modal );
 
     keyWidget->setCheckActionCollections( QList<KActionCollection*>() << ac );
-
-    //TODO tab order in designer!
-    setTabOrder( snippetText, keyWidget );
-    setTabOrder( keyWidget, btnAdd );
-    setTabOrder( btnAdd, btnCancel );
 }
 
 /*
