@@ -9,9 +9,8 @@
 using Ui::SnippetDlgBase;
 
 class KActionCollection;
-class KShortcut;
 
-class SnippetDlg : public KDialog, public SnippetDlgBase
+class SnippetDlg : public QDialog, public SnippetDlgBase
 {
     Q_OBJECT
 
