@@ -2,10 +2,8 @@
                           filter_oe.cxx  -  Outlook Express mail import
                              -------------------
     begin                : Sat Feb 1 2003
-    copyright            : (C) 2003 by Laurence Anderson
-                           (C) 2005 by Danny Kukawka
-    email                : l.d.anderson@warwick.ac.uk
-                           danny.Kukawka@web.de
+    copyright            : (C) 2003 by Laurence Anderson <l.d.anderson@warwick.ac.uk>
+                           (C) 2005 by Danny Kukawka <danny.Kukawka@web.de>
  ***************************************************************************/
 
 /***************************************************************************
@@ -49,7 +47,6 @@ FilterOE::FilterOE() :
 
 FilterOE::~FilterOE()
 {
-    endImport();
 }
 
 void FilterOE::import(FilterInfo *info)
@@ -90,7 +87,7 @@ void FilterOE::import(FilterInfo *info)
     }
 
     int n=0;
-    for ( QStringList::Iterator mailFile = files.begin(); mailFile != files.end(); ++mailFile ) {
+    for ( QStringList::ConstIterator mailFile = files.constBegin(); mailFile != files.constEnd(); ++mailFile ) {
         if ( info->shouldTerminate() ) break;
         importMailBox(info, dir.filePath(*mailFile));
         info->setOverall(100 * ++n  / files.count());
@@ -400,7 +397,7 @@ QString FilterOE::getFolderName(QString filename)
 
     while (!found)
     {
-        for ( FolderStructureIterator it = folderStructure.begin(); it != folderStructure.end(); it++) {
+        for ( FolderStructureIterator it = folderStructure.begin(); it != folderStructure.end(); ++it) {
             FolderStructure tmp = *it;
             if(foundFilename == false) {
                 QString _tmpFileName = tmp[1];
