@@ -18,8 +18,8 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *******************************************************************/
 
-#include <QFont>
-#include <QPixmap>
+#include "knoteedit.h"
+#include "knote.h"
 
 #include <kaction.h>
 #include <kactioncollection.h>
@@ -34,47 +34,22 @@
 #include <ktoggleaction.h>
 #include <kurl.h>
 
-#include "knoteedit.h"
+#include <QFont>
+#include <QPixmap>
 
 static const short SEP = 5;
 static const short ICON_SIZE = 10;
 
 
 KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
-  : KTextEdit( parent ), m_editMenu( 0 )
+  : KTextEdit( parent ), m_note( 0 )
 {
   setAcceptDrops( true );
   setWordWrapMode( QTextOption::WordWrap );
   setLineWrapMode( WidgetWidth );
   setAutoFormatting( AutoAll );
-  
-  // create the actions for the RMB menu
-  QAction * undo = KStandardAction::undo( this, SLOT( undo() ), actions );
-  QAction * redo = KStandardAction::redo( this, SLOT( redo() ), actions );
-  undo->setEnabled( document()->isUndoAvailable() );
-  redo->setEnabled( document()->isRedoAvailable() );
-  
-  m_cut = KStandardAction::cut( this, SLOT( cut() ), actions );
-  m_copy = KStandardAction::copy( this, SLOT( copy() ), actions );
-  m_paste = KStandardAction::paste( this, SLOT( paste() ), actions );
-  
-  m_cut->setEnabled( false );
-  m_copy->setEnabled( false );
-  m_paste->setEnabled( true );
-  
-  connect( this, SIGNAL( undoAvailable( bool ) ),
-           undo, SLOT( setEnabled( bool ) ) );
-  connect( this, SIGNAL( redoAvailable( bool ) ),
-           redo, SLOT( setEnabled( bool ) ) );
-  
-  connect( this, SIGNAL( copyAvailable( bool ) ),
-           this, SLOT( slotCutEnabled( bool ) ) );
-  connect( this, SIGNAL( copyAvailable( bool ) ),
-           m_copy, SLOT( setEnabled( bool ) ) );
-  
-  KStandardAction::clear( this, SLOT( clear() ), actions );
-  KStandardAction::selectAll( this, SLOT( selectAll() ), actions );
-  
+  setCheckSpellingEnabled( true );
+
   // create the actions modifying the text format
   m_textBold  = new KToggleAction( KIcon( "format-text-bold" ), i18n( "Bold" ),
                                    this );
@@ -92,7 +67,7 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
                                         i18n( "Strike Out" ), this );
   actions->addAction( "format_strikeout", m_textStrikeOut );
   m_textStrikeOut->setShortcut( QKeySequence( Qt::CTRL + Qt::Key_S ) );
-  
+
   connect( m_textBold, SIGNAL( toggled( bool ) ), SLOT( textBold( bool ) ) );
   connect( m_textItalic, SIGNAL( toggled( bool ) ),
            SLOT( setFontItalic( bool ) ) );
@@ -100,7 +75,7 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
            SLOT( setFontUnderline( bool ) ) );
   connect( m_textStrikeOut, SIGNAL( toggled( bool ) ),
            SLOT( textStrikeOut( bool ) ) );
-  
+
   m_textAlignLeft = new KToggleAction( KIcon( "format-justify-left" ),
                                        i18n( "Align Left" ), this );
   actions->addAction( "format_alignleft", m_textAlignLeft );
@@ -126,20 +101,17 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
   connect( m_textAlignBlock, SIGNAL( triggered( bool ) ),
            SLOT( textAlignBlock() ) );
   m_textAlignBlock->setShortcut( QKeySequence( Qt::ALT + Qt::Key_B ) );
-  
+
   QActionGroup *group = new QActionGroup( this );
   group->addAction( m_textAlignLeft );
   group->addAction( m_textAlignCenter );
   group->addAction( m_textAlignRight );
   group->addAction( m_textAlignBlock );
-  
+
   m_textList  = new KToggleAction( KIcon( "format-list-ordered" ), i18n( "List" ), this );
   actions->addAction( "format_list", m_textList );
   connect( m_textList, SIGNAL( triggered( bool ) ), SLOT( textList() ) );
-  
-  group = new QActionGroup( this );
-  group->addAction( m_textList );
-  
+
   m_textSuper  = new KToggleAction( KIcon( "format-text-superscript" ),
                                     i18n( "Superscript" ), this );
   actions->addAction( "format_super", m_textSuper );
@@ -149,11 +121,8 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
                                   this );
   actions->addAction( "format_sub", m_textSub );
   connect( m_textSub, SIGNAL( triggered( bool ) ), SLOT( textSubScript() ) );
-  
-  group = new QActionGroup( this );
-  group->addAction( m_textSuper );
-  group->addAction( m_textSub );
-  
+
+
   m_textIncreaseIndent = new KAction( KIcon( "format-indent-more" ),
                                       i18n( "Increase Indent" ), this );
   actions->addAction( "format_increaseindent", m_textIncreaseIndent );
@@ -161,7 +130,7 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
                                                    Qt::Key_I ) );
   connect( m_textIncreaseIndent, SIGNAL( triggered( bool ) ),
            SLOT( textIncreaseIndent() ) );
-  
+
   m_textDecreaseIndent = new KAction(  KIcon( "format-indent-less" ),
                                        i18n( "Decrease Indent" ), this );
   actions->addAction( "format_decreaseindent", m_textDecreaseIndent );
@@ -169,46 +138,45 @@ KNoteEdit::KNoteEdit( KActionCollection *actions, QWidget *parent )
                                                    Qt::Key_D ) );
   connect( m_textDecreaseIndent, SIGNAL( triggered( bool ) ), SLOT(
            textDecreaseIndent() ) );
-  
+
   group = new QActionGroup( this );
   group->addAction( m_textIncreaseIndent );
   group->addAction( m_textDecreaseIndent );
-  
+
   QPixmap pix( ICON_SIZE, ICON_SIZE );
   pix.fill( Qt::black ); // just a dummy, gets updated before widget is shown
   m_textColor  = new KAction( i18n( "Text Color..." ), this );
   actions->addAction( "format_color", m_textColor );
-  ( ( QAction * )m_textColor )->setIcon( pix );
+  m_textColor->setIcon( pix );
   connect( m_textColor, SIGNAL( triggered( bool ) ), SLOT( slotTextColor() ) );
-  
+
+  KAction *act = new KAction(KIcon( "format-fill-color" ), i18n( "Text Background Color..." ), this );
+  actions->addAction( "text_background_color", act );
+  connect( act, SIGNAL( triggered( bool ) ), SLOT( slotTextBackgroundColor() ) );
+
   m_textFont  = new KFontAction( i18n( "Text Font" ), this );
   actions->addAction( "format_font", m_textFont );
   connect( m_textFont, SIGNAL( triggered( const QString & ) ),
            this, SLOT( setFontFamily( const QString & ) ) );
-  
+
   m_textSize  = new KFontSizeAction( i18n( "Text Size" ), this );
   actions->addAction( "format_size", m_textSize );
   connect( m_textSize, SIGNAL( fontSizeChanged( int ) ),
-           this, SLOT( setFontWeight ( int ) ) );
-  
+           this, SLOT( setTextFontSize( int ) ) );
+
   // QTextEdit connections
   connect( this, SIGNAL( currentCharFormatChanged( const QTextCharFormat & ) ),
            SLOT( slotCurrentCharFormatChanged( const QTextCharFormat & ) ) );
-  
-#ifdef __GNUC__
-#warning moving the cursor through alignment changes does not update the button!
-#endif
+  connect( this, SIGNAL( cursorPositionChanged () ),
+           SLOT( slotCursorPositionChanged() ) );
   slotCurrentCharFormatChanged( currentCharFormat() );
+  slotCursorPositionChanged();
 }
 
 KNoteEdit::~KNoteEdit()
 {
 }
 
-void KNoteEdit::slotCutEnabled( bool b )
-{
-    m_cut->setEnabled( b && !isReadOnly() );
-}
 
 void KNoteEdit::setText( const QString& text )
 {
@@ -230,16 +198,12 @@ QString KNoteEdit::text() const
 
 void KNoteEdit::setTextFont( const QFont &font )
 {
-  QTextCharFormat f;
-  f.setFont( font );
-  setTextFormat( f );
+    setCurrentFont( font );
 }
 
-void KNoteEdit::setTextColor( const QColor &color )
+void KNoteEdit::setTextFontSize( int size )
 {
-  QTextCharFormat f;
-  f.setForeground( QBrush( color ) );
-  setTextFormat( f );
+  setFontPointSize( size );
 }
 
 void KNoteEdit::setTabStop( int tabs )
@@ -261,10 +225,10 @@ void KNoteEdit::setRichText( bool f )
   if ( f == acceptRichText() ) {
     return;
   }
-  
+
   setAcceptRichText( f );
-  
-  QString t = toPlainText();
+
+  const QString t = toPlainText();
   if ( f ) {
     // if the note contains html source try to render it
     if ( Qt::mightBeRichText( t ) ) {
@@ -272,7 +236,7 @@ void KNoteEdit::setRichText( bool f )
     } else {
       setPlainText( t );
     }
-    
+
     enableRichTextActions();
   } else {
     setPlainText( t );
@@ -296,12 +260,30 @@ void KNoteEdit::textStrikeOut( bool s )
 
 void KNoteEdit::slotTextColor()
 {
+  if ( m_note )
+      m_note->blockEmitDataChanged( true );
   QColor c = textColor();
   int ret = KColorDialog::getColor( c, this );
-  
+
   if ( ret == QDialog::Accepted ) {
     setTextColor( c );
   }
+  if ( m_note )
+      m_note->blockEmitDataChanged( false );
+}
+
+void KNoteEdit::slotTextBackgroundColor()
+{
+  if ( m_note )
+      m_note->blockEmitDataChanged( true );
+  QColor c = textBackgroundColor();
+  int ret = KColorDialog::getColor( c, this );
+
+  if ( ret == QDialog::Accepted ) {
+    setTextBackgroundColor( c );
+  }
+  if ( m_note )
+      m_note->blockEmitDataChanged( false );
 }
 
 void KNoteEdit::textAlignLeft()
@@ -330,34 +312,36 @@ void KNoteEdit::textAlignBlock()
 
 void KNoteEdit::textList()
 {
-  QTextCursor c = textCursor();
-  c.beginEditBlock();
-  
-  if ( m_textList->isChecked() ) {
-    QTextListFormat lf;
-    QTextBlockFormat bf = c.blockFormat();
-    
-    lf.setIndent( bf.indent() + 1 );
-    bf.setIndent( 0 );
-    
-    lf.setStyle( QTextListFormat::ListDisc );
-    
-    c.setBlockFormat( bf );
-    c.createList( lf );
-  } else {
-    QTextBlockFormat bf;
-    bf.setObjectIndex( -1 );
-    c.mergeBlockFormat( bf );
-  }
-  
-  c.endEditBlock();
+    QTextCursor c = textCursor();
+    c.beginEditBlock();
+
+    if ( m_textList->isChecked() ) {
+        QTextListFormat lf;
+        QTextBlockFormat bf = c.blockFormat();
+
+        lf.setIndent( bf.indent() + 1 );
+        bf.setIndent( 0 );
+
+        lf.setStyle( QTextListFormat::ListDisc );
+
+        c.setBlockFormat( bf );
+        c.createList( lf );
+    } else {
+        QTextBlockFormat bf;
+        bf.setObjectIndex( -1 );
+        c.setBlockFormat( bf );
+
+    }
+
+    c.endEditBlock();
 }
 
 void KNoteEdit::textSuperScript()
 {
   QTextCharFormat f;
-  
   if ( m_textSuper->isChecked() ) {
+      if ( m_textSub->isChecked() )
+          m_textSub->setChecked( false );
     f.setVerticalAlignment( QTextCharFormat::AlignSuperScript );
   } else {
     f.setVerticalAlignment( QTextCharFormat::AlignNormal );
@@ -368,9 +352,10 @@ void KNoteEdit::textSuperScript()
 void KNoteEdit::textSubScript()
 {
   QTextCharFormat f;
-  
   if ( m_textSub->isChecked() ) {
-    f.setVerticalAlignment( QTextCharFormat::AlignSubScript );
+      if ( m_textSuper->isChecked() )
+          m_textSuper->setChecked( false );
+      f.setVerticalAlignment( QTextCharFormat::AlignSubScript );
   } else {
     f.setVerticalAlignment( QTextCharFormat::AlignNormal );
   }
@@ -388,7 +373,7 @@ void KNoteEdit::textDecreaseIndent()
 {
   QTextBlockFormat f = textCursor().blockFormat();
   short int curIndent = f.indent();
-  
+
   if ( curIndent > 0 ) {
     f.setIndent( curIndent - 1 );
   }
@@ -398,13 +383,6 @@ void KNoteEdit::textDecreaseIndent()
 
 /** protected methods **/
 
-void KNoteEdit::contextMenuEvent( QContextMenuEvent *e )
-{
-  if ( m_editMenu ) {
-    m_editMenu->popup( e->globalPos() );
-  }
-}
-
 void KNoteEdit::dragEnterEvent( QDragEnterEvent *e )
 {
   const QMimeData *md = e->mimeData();
@@ -418,22 +396,26 @@ void KNoteEdit::dragEnterEvent( QDragEnterEvent *e )
 void KNoteEdit::dropEvent( QDropEvent *e )
 {
   const QMimeData *md = e->mimeData();
-  
+
   if ( KUrl::List::canDecode( md ) ) {
     KUrl::List list = KUrl::List::fromMimeData( md );
-    for ( KUrl::List::Iterator it = list.begin(); it != list.end(); ++it ) {
-      if ( it != list.begin() ) {
+    KUrl::List::ConstIterator begin = list.constBegin();
+    KUrl::List::ConstIterator end = list.constEnd();
+    for ( KUrl::List::ConstIterator it = begin; it != end; ++it ) {
+      if ( it != begin ) {
         insertPlainText( ", " );
       }
       insertPlainText( ( *it ).prettyUrl() );
     }
-  } else { KTextEdit::dropEvent( e ); }
+  } else {
+      KTextEdit::dropEvent( e );
+  }
 }
 
 void KNoteEdit::keyPressEvent( QKeyEvent *e )
 {
   KTextEdit::keyPressEvent( e );
-  
+
   if ( m_autoIndentMode &&
        ( ( e->key() == Qt::Key_Return ) || ( e->key() == Qt::Key_Enter ) ) ) {
     autoIndent();
@@ -443,7 +425,7 @@ void KNoteEdit::keyPressEvent( QKeyEvent *e )
 void KNoteEdit::focusInEvent( QFocusEvent *e )
 {
   KTextEdit::focusInEvent( e );
-  
+
   setVerticalScrollBarPolicy( Qt::ScrollBarAsNeeded );
   setHorizontalScrollBarPolicy( Qt::ScrollBarAsNeeded );
 }
@@ -452,7 +434,7 @@ void KNoteEdit::focusOutEvent( QFocusEvent *e )
 {
   setVerticalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
   setHorizontalScrollBarPolicy( Qt::ScrollBarAlwaysOff );
-  
+
   KTextEdit::focusOutEvent( e );
 }
 
@@ -462,30 +444,18 @@ void KNoteEdit::slotCurrentCharFormatChanged( const QTextCharFormat &f )
 {
   // font changes
   m_textFont->setFont( f.fontFamily() );
-  m_textSize->setFontSize( ( int ) f.fontPointSize() );
-  
+  m_textSize->setFontSize( (f.fontPointSize()>0 ) ?  ( int ) f.fontPointSize() :10);
+
   m_textBold->setChecked( f.font().bold() );
   m_textItalic->setChecked( f.fontItalic() );
   m_textUnderline->setChecked( f.fontUnderline() );
   m_textStrikeOut->setChecked( f.fontStrikeOut() );
-  
+
   // color changes
   QPixmap pix( ICON_SIZE, ICON_SIZE );
   pix.fill( f.foreground().color() );
   m_textColor->QAction::setIcon( pix );
-  
-  // alignment changes
-  Qt::Alignment a = alignment();
-  if ( a & Qt::AlignLeft ) {
-    m_textAlignLeft->setChecked( true );
-  } else if ( a & Qt::AlignHCenter ) {
-    m_textAlignCenter->setChecked( true );
-  } else if ( a & Qt::AlignRight ) {
-    m_textAlignRight->setChecked( true );
-  } else if ( a & Qt::AlignJustify ) {
-    m_textAlignBlock->setChecked( true );
-  }
-  
+
   // vertical alignment changes
   QTextCharFormat::VerticalAlignment va = f.verticalAlignment();
   if ( va == QTextCharFormat::AlignNormal ) {
@@ -499,35 +469,50 @@ void KNoteEdit::slotCurrentCharFormatChanged( const QTextCharFormat &f )
 }
 
 
+void KNoteEdit::slotCursorPositionChanged()
+{
+    // alignment changes
+    Qt::Alignment a = alignment();
+    if ( a & Qt::AlignLeft ) {
+        m_textAlignLeft->setChecked( true );
+    } else if ( a & Qt::AlignHCenter ) {
+        m_textAlignCenter->setChecked( true );
+    } else if ( a & Qt::AlignRight ) {
+        m_textAlignRight->setChecked( true );
+    } else if ( a & Qt::AlignJustify ) {
+        m_textAlignBlock->setChecked( true );
+    }
+}
+
 /** private methods **/
 
 void KNoteEdit::autoIndent()
 {
   QTextCursor c = textCursor();
   QTextBlock b = c.block();
-  
+
   QString string;
   while ( ( b.previous().length() > 0 ) && string.trimmed().isEmpty() ) {
     b = b.previous();
     string = b.text();
   }
-  
+
   if ( string.trimmed().isEmpty() ) {
     return;
   }
-  
+
   // This routine returns the whitespace before the first non white space
   // character in string.
   // It is assumed that string contains at least one non whitespace character
   // ie \n \r \t \v \f and space
   QString indentString;
-  
-  int len = string.length();
+
+  const int len = string.length();
   int i = 0;
   while ( i < len && string.at( i ).isSpace() ) {
     indentString += string.at( i++ );
   }
-  
+
   if ( !indentString.isEmpty() ) {
     c.insertText( indentString );
   }
@@ -550,21 +535,21 @@ void KNoteEdit::enableRichTextActions()
   m_textColor->setEnabled( true );
   m_textFont->setEnabled( true );
   m_textSize->setEnabled( true );
-  
+
   m_textBold->setEnabled( true );
   m_textItalic->setEnabled( true );
   m_textUnderline->setEnabled( true );
   m_textStrikeOut->setEnabled( true );
-  
+
   m_textAlignLeft->setEnabled( true );
   m_textAlignCenter->setEnabled( true );
   m_textAlignRight->setEnabled( true );
   m_textAlignBlock->setEnabled( true );
-  
+
   m_textList->setEnabled( true );
   m_textSuper->setEnabled( true );
   m_textSub->setEnabled( true );
-  
+
   m_textIncreaseIndent->setEnabled( true );
   m_textDecreaseIndent->setEnabled( true );
 }
@@ -574,21 +559,21 @@ void KNoteEdit::disableRichTextActions()
   m_textColor->setEnabled( false );
   m_textFont->setEnabled( false );
   m_textSize->setEnabled( false );
-  
+
   m_textBold->setEnabled( false );
   m_textItalic->setEnabled( false );
   m_textUnderline->setEnabled( false );
   m_textStrikeOut->setEnabled( false );
-  
+
   m_textAlignLeft->setEnabled( false );
   m_textAlignCenter->setEnabled( false );
   m_textAlignRight->setEnabled( false );
   m_textAlignBlock->setEnabled( false );
-  
+
   m_textList->setEnabled( false );
   m_textSuper->setEnabled( false );
   m_textSub->setEnabled( false );
-  
+
   m_textIncreaseIndent->setEnabled( false );
   m_textDecreaseIndent->setEnabled( false );
 }
