@@ -2,6 +2,7 @@
   This file is part of the KDE Kontact.
 
   Copyright (C) 2003 Cornelius Schumacher <schumacher@kde.org>
+  Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
@@ -19,14 +20,13 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include "core.h"
-
 #include "sidepanebase.h"
+#include "core.h"
 
 using namespace Kontact;
 
-SidePaneBase::SidePaneBase( Core *core, QWidget *parent, const char *name )
-  : QVBox( parent, name ), mCore( core )
+SidePaneBase::SidePaneBase( Core *core, QWidget *parent )
+  : KVBox( parent ), mCore( core )
 {
 }
 
@@ -34,19 +34,9 @@ SidePaneBase::~SidePaneBase()
 {
 }
 
-Core* SidePaneBase::core() const
+Core *SidePaneBase::core() const
 {
   return mCore;
 }
 
-void SidePaneBase::setActionCollection( KActionCollection *actionCollection )
-{
-  mActionCollection = actionCollection;
-}
-
-KActionCollection *SidePaneBase::actionCollection() const
-{
-  return mActionCollection;
-}
-
 #include "sidepanebase.moc"
