@@ -78,7 +78,7 @@ ArchiveDialog::ArchiveDialog( Calendar *cal, QWidget *parent )
            "then deletes them in the current calendar. If the archive file "
            "already exists they will be added. "
            "(<link url=\"whatsthis:In order to add an archive "
-           "to your calendar, use the &quot;Merge Calendar&quot; function. "
+           "to your calendar, use the Merge Calendar function. "
            "You can view an archive by opening it in KOrganizer like any "
            "other calendar. It is not saved in a special format, but as "
            "vCalendar.\">How to restore</link>)" ) );
@@ -247,8 +247,9 @@ void ArchiveDialog::slotUser1()
     }
     // Force filename to be ending with vCalendar extension
     QString filename = destUrl.fileName();
-    if ( !filename.endsWith( ".vcs" ) && !filename.endsWith( ".ics" ) ) {
-      filename.append( ".ics" );
+    if ( !filename.endsWith( QLatin1String( ".vcs" ) ) &&
+         !filename.endsWith( QLatin1String( ".ics" ) ) ) {
+      filename.append( QLatin1String( ".ics" ) );
       destUrl.setFileName( filename );
     }
 
