@@ -27,33 +27,29 @@
 #define CALENDARVIEW_H
 
 #include "korganizer_export.h"
-#include <korganizer/koeventviewer.h>
-#include <korganizer/calendarviewbase.h>
+#include "interfaces/korganizer/calendarviewbase.h"
 
-#include <kcal/scheduler.h>
-
-#include <kfile.h>
-
-#include <QWidget>
-#include <QMap>
 #include <QList>
+#include <QMap>
+#include <QWidget>
 
 class CalPrinter;
-class KOViewManager;
-class KODialogManager;
-class KOTodoView;
-class KOEventEditor;
-class DateNavigatorContainer;
-class DateNavigator;
-class KOIncidenceEditor;
-class NavigatorBar;
 class DateChecker;
+class DateNavigator;
+class DateNavigatorContainer;
+class KODialogManager;
+class KOEventEditor;
+class KOEventViewer;
+class KOIncidenceEditor;
+class KOTodoView;
+class KOViewManager;
+class NavigatorBar;
 
 class KVBox;
 
 class QByteArray;
-class QStackedWidget;
 class QSplitter;
+class QStackedWidget;
 
 namespace KOrg {
   class History;
@@ -136,7 +132,14 @@ class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
     DateNavigator *dateNavigator() const { return mDateNavigator; }
 
     KOIncidenceEditor *editorDialog( Incidence *incidence ) const;
-    IncidenceChangerBase *incidenceChanger() const { return mChanger; }
+    KOrg::IncidenceChangerBase *incidenceChanger() const { return mChanger; }
+
+    /*
+     * Informs the date navigator which incidence types should be used
+     * to embolden days, this function is mainly called when the view changes
+     * or when the config changes.
+     */
+    void updateHighlightModes();
 
     QDate startDate();
     QDate endDate();
@@ -405,9 +408,9 @@ class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
     void newJournal( const QDate &date );
     void newJournal( const QString &text, const QDate &date=QDate() );
 
-    void toggleAlarm( Incidence * );
-    void dissociateOccurrence( Incidence *, const QDate & );
-    void dissociateFutureOccurrence( Incidence *, const QDate & );
+    void toggleAlarm( Incidence *incidence );
+    void toggleTodoCompleted( Incidence *incidence );
+    void dissociateOccurrences( Incidence *incidence, const QDate &date );
 
     /**
       Check if clipboard contains vCalendar event. The signal pasteEnabled() is
@@ -468,6 +471,7 @@ class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
       parameters.
     */
     void print();
+    void printPreview();
 
     /** Export as HTML file */
     void exportWeb();
@@ -605,10 +609,9 @@ class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
     /**
       Returns the best guess at the current active date in the view.
 
-      @param fallbackToToday If guessing doesn't work, some views will prefer 
-                             today to be returned instead of the first select date
-                             in the day matrix, Journal view for example.
-      
+      @param fallbackToToday If guessing doesn't work, some views will prefer
+      today to be returned instead of the first select date in the day matrix,
+      Journal view for example.
     */
     QDate activeDate( bool fallbackToToday = false );
 
@@ -636,9 +639,11 @@ class KORGANIZERPRIVATE_EXPORT CalendarView : public KOrg::CalendarViewBase,
   private:
     void init();
 
-
     void createPrinter();
 
+    void dissociateOccurrence( Incidence *, const QDate & );
+    void dissociateFutureOccurrence( Incidence *, const QDate & );
+
     void calendarModified( bool, Calendar * );
 
     // Helper function for purgeCompleted that recursively purges a todo and
