@@ -23,16 +23,19 @@
 */
 
 #include "incidencechanger.h"
-#include "koprefs.h"
 #include "kogroupware.h"
+#include "koprefs.h"
 #include "mailscheduler.h"
 
-#include <kcal/freebusy.h>
-#include <kcal/dndfactory.h>
+#include <KCal/AssignmentVisitor>
+#include <KCal/CalendarResources>
+#include <KCal/DndFactory>
+#include <KCal/FreeBusy>
+#include <KCal/Incidence>
 
-#include <kdebug.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <KDebug>
+#include <KLocale>
+#include <KMessageBox>
 
 bool IncidenceChanger::beginChange( Incidence *incidence )
 {
@@ -43,7 +46,7 @@ bool IncidenceChanger::beginChange( Incidence *incidence )
   return mCalendar->beginChange( incidence );
 }
 
-bool IncidenceChanger::sendGroupwareMessage( Incidence *incidence,
+bool IncidenceChanger::sendGroupwareMessage( KCal::Incidence *incidence,
                                              KCal::iTIPMethod method, bool deleting )
 {
   if ( KOPrefs::instance()->thatIsMe( incidence->organizer().email() ) &&
@@ -74,7 +77,7 @@ void IncidenceChanger::cancelAttendees( Incidence *incidence )
       // manually.
       // FIXME: Groupware schedulling should be factored out to it's own class
       //        anyway
-      KCal::MailScheduler scheduler( mCalendar );
+      MailScheduler scheduler( mCalendar );
       scheduler.performTransaction( incidence, iTIPCancel );
     }
   }
@@ -113,7 +116,7 @@ bool IncidenceChanger::deleteIncidence( Incidence *incidence )
       bool notifyOrganizer = false;
       for ( QStringList::ConstIterator it = myEmails.begin(); it != myEmails.end(); ++it ) {
         QString email = *it;
-        Attendee *me = tmp->attendeeByMail(email);
+        Attendee *me = tmp->attendeeByMail( email );
         if ( me ) {
           if ( me->status() == KCal::Attendee::Accepted ||
                me->status() == KCal::Attendee::Delegated ) {
@@ -128,7 +131,7 @@ bool IncidenceChanger::deleteIncidence( Incidence *incidence )
       }
 
       if ( notifyOrganizer ) {
-        KCal::MailScheduler scheduler( mCalendar );
+        MailScheduler scheduler( mCalendar );
         scheduler.performTransaction( tmp, KCal::iTIPReply );
       }
     }
@@ -172,7 +175,7 @@ class IncidenceChanger::ComparisonVisitor : public IncidenceBase::Visitor
   protected:
     bool visit( Event *event )
     {
-      Event *ev2 = dynamic_cast<Event*>(mIncidence2);
+      Event *ev2 = dynamic_cast<Event*>( mIncidence2 );
       if ( event && ev2 ) {
         return *event == *ev2;
       } else {
@@ -215,64 +218,6 @@ class IncidenceChanger::ComparisonVisitor : public IncidenceBase::Visitor
     IncidenceBase *mIncidence2;
 };
 
-class IncidenceChanger::AssignmentVisitor : public IncidenceBase::Visitor
-{
-  public:
-    AssignmentVisitor() {}
-    bool act( IncidenceBase *incidence, IncidenceBase *inc2 )
-    {
-      mIncidence2 = inc2;
-      if ( incidence ) {
-        return incidence->accept( *this );
-      } else {
-        return false;
-      }
-    }
-  protected:
-    bool visit( Event *event )
-    {
-      Event *ev2 = dynamic_cast<Event*>( mIncidence2 );
-      if ( event && ev2 ) {
-        *event = *ev2;
-        return true;
-      } else {
-        return false;
-      }
-    }
-    bool visit( Todo *todo )
-    {
-      Todo *to2 = dynamic_cast<Todo*>( mIncidence2 );
-      if ( todo && to2 ) {
-        *todo = *to2;
-        return true;
-      } else {
-        return false;
-      }
-    }
-    bool visit( Journal *journal )
-    {
-      Journal *j2 = dynamic_cast<Journal*>(mIncidence2);
-      if ( journal && j2 ) {
-        *journal = *j2;
-        return true;
-      } else {
-        return false;
-      }
-    }
-    bool visit( FreeBusy *fb )
-    {
-      FreeBusy *fb2 = dynamic_cast<FreeBusy*>( mIncidence2 );
-      if ( fb && fb2 ) {
-        *fb = *fb2;
-        return true;
-      } else {
-        return false;
-      }
-    }
-  protected:
-    IncidenceBase *mIncidence2;
-};
-
 bool IncidenceChanger::incidencesEqual( Incidence *inc1, Incidence *inc2 )
 {
   ComparisonVisitor v;
@@ -281,8 +226,12 @@ bool IncidenceChanger::incidencesEqual( Incidence *inc1, Incidence *inc2 )
 
 bool IncidenceChanger::assignIncidence( Incidence *inc1, Incidence *inc2 )
 {
+  if ( !inc1 || !inc2 ) {
+    return false;
+  }
+
   AssignmentVisitor v;
-  return v.act( inc1, inc2 );
+  return v.assign( inc1, inc2 );
 }
 
 bool IncidenceChanger::myAttendeeStatusChanged( Incidence *oldInc, Incidence *newInc )
@@ -339,19 +288,17 @@ bool IncidenceChanger::changeIncidence( Incidence *oldinc, Incidence *newinc,
 
 bool IncidenceChanger::addIncidence( Incidence *incidence, QWidget *parent )
 {
-  kDebug() << "\"" << incidence->summary() << "\"";
-  if ( KOPrefs::instance()->mUseGroupwareCommunication ) {
-    if ( !KOGroupware::instance()->sendICalMessage( parent,
-                                                    KCal::iTIPRequest,
-                                                    incidence ) ) {
-      return false;
-    }
+  CalendarResources *stdcal = dynamic_cast<CalendarResources*>( mCalendar );
+  if( stdcal && !stdcal->hasCalendarResources() ) {
+    KMessageBox::sorry( parent, i18n( "No resources found, item cannot be added." ) );
+    return false;
   }
+
+  kDebug() << "\"" << incidence->summary() << "\"";
   // FIXME: This is a nasty hack, since we need to set a parent for the
   //        resource selection dialog. However, we don't have any UI methods
   //        in the calendar, only in the CalendarResources::DestinationPolicy
   //        So we need to type-cast it and extract it from the CalendarResources
-  CalendarResources *stdcal = dynamic_cast<CalendarResources*>( mCalendar );
   QWidget *tmpparent = 0;
   if ( stdcal ) {
     tmpparent = stdcal->dialogParentWidget();
@@ -363,7 +310,7 @@ bool IncidenceChanger::addIncidence( Incidence *incidence, QWidget *parent )
     // widgets sooner or later
     stdcal->setDialogParentWidget( tmpparent );
   }
-  if ( !success ) {
+  if ( !success && stdcal ) {
     // We can have a failure if the user pressed [cancel] in the resource
     // selectdialog, so check the exception.
     ErrorFormat *e = stdcal->exception();
@@ -375,6 +322,15 @@ bool IncidenceChanger::addIncidence( Incidence *incidence, QWidget *parent )
     }
     return false;
   }
+
+  if ( KOPrefs::instance()->mUseGroupwareCommunication ) {
+    if ( !KOGroupware::instance()->sendICalMessage( parent,
+                                                    KCal::iTIPRequest,
+                                                    incidence ) ) {
+      kError() << "sendIcalMessage failed.";
+    }
+  }
+
   emit incidenceAdded( incidence );
   return true;
 }
