@@ -24,11 +24,14 @@
 
 #include "mailscheduler.h"
 #include "komailclient.h"
+#include "incidencechanger.h"
 
+#include <kcal/calendar.h>
 #include <kcal/event.h>
 #include <kcal/icalformat.h>
 
 #include <kdebug.h>
+#include <klocale.h>
 #include <kstandarddirs.h>
 
 #include <QDir>
@@ -37,10 +40,8 @@
 #include <QTextStream>
 #include <QList>
 
-using namespace KCal;
-
 MailScheduler::MailScheduler( Calendar *calendar )
-  : IMIPScheduler( calendar )
+  : Scheduler( calendar )
 {
 }
 
@@ -80,7 +81,12 @@ bool MailScheduler::performTransaction( IncidenceBase *incidence,
        method == iTIPDeclineCounter ) {
     status = mailer.mailAttendees( incidence, messageText );
   } else {
-    status = mailer.mailOrganizer( incidence, messageText );
+    QString subject;
+    Incidence *inc = dynamic_cast<Incidence*>( incidence );
+    if ( inc && method == iTIPCounter ) {
+      subject = i18n( "Counter proposal: %1", inc->summary() );
+    }
+    status = mailer.mailOrganizer( incidence, messageText, subject );
   }
   return status;
 }
@@ -95,7 +101,7 @@ QList<ScheduleMessage*> MailScheduler::retrieveTransactions()
   QDir incomingDir( incomingDirName );
   QStringList incoming = incomingDir.entryList( QDir::Files );
   QStringList::ConstIterator it;
-  for ( it = incoming.begin(); it != incoming.end(); ++it ) {
+  for ( it = incoming.constBegin(); it != incoming.constEnd(); ++it ) {
     kDebug() << "-- File:" << (*it);
 
     QFile f( incomingDirName + '/' + (*it) );
@@ -152,3 +158,31 @@ QString MailScheduler::freeBusyDir()
 {
   return KStandardDirs::locateLocal( "data", "korganizer/freebusy" );
 }
+
+bool MailScheduler::acceptCounterProposal( Incidence *incidence )
+{
+  if ( !incidence ) {
+    return false;
+  }
+
+  Incidence *exInc = mCalendar->incidence( incidence->uid() );
+  if ( !exInc ) {
+    exInc = mCalendar->incidenceFromSchedulingID( incidence->uid() );
+  }
+
+  incidence->setRevision( incidence->revision() + 1 );
+  if ( exInc ) {
+    incidence->setRevision( qMax( incidence->revision(), exInc->revision() + 1 ) );
+    // some stuff we don't want to change, just to be safe
+    incidence->setSchedulingID( exInc->schedulingID() );
+    incidence->setUid( exInc->uid() );
+
+    mCalendar->beginChange( exInc );
+    IncidenceChanger::assignIncidence( exInc, incidence );
+    exInc->updated();
+    mCalendar->endChange( exInc );
+  } else {
+    mCalendar->addIncidence( incidence );
+  }
+  return true;
+}
