@@ -29,7 +29,9 @@
 #include <KVBox>
 
 #include <Q3ScrollView>
-#include <QLayout>
+#include <QHBoxLayout>
+#include <QLabel>
+#include <QResizeEvent>
 #include <QSplitter>
 
 using namespace KOrg;
@@ -39,7 +41,7 @@ MultiAgendaView::MultiAgendaView( Calendar *cal, QWidget *parent )
     mUpdateOnShow( true ),
     mPendingChanges( true )
 {
-  QBoxLayout *topLevelLayout = new QHBoxLayout( this );
+  QHBoxLayout *topLevelLayout = new QHBoxLayout( this );
   topLevelLayout->setSpacing( 0 );
   topLevelLayout->setMargin( 0 );
 
@@ -193,11 +195,8 @@ void MultiAgendaView::setupViews()
              SIGNAL(pasteIncidenceSignal()) );
     connect( agenda, SIGNAL(toggleAlarmSignal(Incidence*)),
              SIGNAL(toggleAlarmSignal(Incidence*)) );
-    connect( agenda, SIGNAL(dissociateOccurrenceSignal(Incidence*, const QDate&)),
-             SIGNAL(dissociateOccurrenceSignal(Incidence*, const QDate&)) );
-    connect( agenda, SIGNAL(dissociateFutureOccurrenceSignal(Incidence*, const QDate&)),
-             SIGNAL(dissociateFutureOccurrenceSignal(Incidence*, const QDate&)) );
-
+    connect( agenda, SIGNAL(dissociateOccurrencesSignal(Incidence*, const QDate&)),
+             SIGNAL(dissociateOccurrencesSignal(Incidence*, const QDate&)) );
     connect( agenda, SIGNAL(newEventSignal(const QDate&)),
              SIGNAL(newEventSignal(const QDate&)) );
     connect( agenda, SIGNAL(newEventSignal(const QDateTime&)),
@@ -341,20 +340,6 @@ void MultiAgendaView::slotClearTimeSpanSelection()
   }
 }
 
-void MultiAgendaView::setTypeAheadReceiver( QObject *o )
-{
-  foreach ( KOAgendaView *agenda, mAgendaViews ) {
-    agenda->setTypeAheadReceiver( o );
-  }
-}
-
-void MultiAgendaView::finishTypeAhead()
-{
-  foreach ( KOAgendaView *agenda, mAgendaViews ) {
-    agenda->finishTypeAhead();
-  }
-}
-
 void MultiAgendaView::addView( const QString &label, KCal::ResourceCalendar *res,
                                const QString &subResource )
 {
