@@ -38,46 +38,46 @@ DataProxy::DataProxy() : fIterator( fRecords )
 DataProxy::~DataProxy()
 {
 	FUNCTIONSETUP;
-	
+
 	qDeleteAll( fRecords );
 }
 
 QString DataProxy::create( Record *record )
 {
 	FUNCTIONSETUP;
-	
+
 	// Temporary id.
 	QString uniqueId = generateUniqueId();
-	
+
 	// Make sure that the new record has the right id and add the record.
 	record->setId( uniqueId );
-	
-	DEBUGKPILOT << "Record created with id: [" << uniqueId << "]";
-	
+
+	DEBUGKPILOT << "Record created with id: [" << uniqueId << "], description: [" << record->toString() << "]";
+
 	fRecords.insert( uniqueId, record );
-	
+
 	// Update rollback/volatility information.
 	fCreated.insert( uniqueId, false );
 	fCounter.created();
-	
+
 	return uniqueId;
 }
 
 void DataProxy::remove( const QString &id )
 {
 	FUNCTIONSETUP;
-	
+
 	Record *rec = fRecords.value( id );
 	if( rec == 0L )
 	{
 		// No record
 		return;
 	}
-	
-	DEBUGKPILOT << "Removing record id: [" << id << "]";
+
+	DEBUGKPILOT << "Removing record id: [" << id << "], description: [" << rec->toString() << "]";
 	// Remove record.
 	fRecords.remove( id );
-	
+
 	// Update rollback/volatility information.
 	fDeletedRecords.insert( rec->id(), rec );
 	fDeleted.insert( rec->id(), false );
@@ -87,7 +87,7 @@ void DataProxy::remove( const QString &id )
 void DataProxy::update( const QString &id, Record *newRecord )
 {
 	FUNCTIONSETUP;
-	
+
 	Record *oldRecord = fRecords.value( id );
 	if( oldRecord == 0L )
 	{
@@ -100,7 +100,7 @@ void DataProxy::update( const QString &id, Record *newRecord )
 	// Make sure that the new record has the right id and update the old record.
 	newRecord->setId( id );
 	fRecords.insert( id, newRecord );
-	
+
 	// Update rollback/volatility information.
 	fOldRecords.insert( id, oldRecord );
 	fCounter.updated();
@@ -114,21 +114,21 @@ QList<QString> DataProxy::ids() const
 const CUDCounter* DataProxy::counter() const
 {
 	FUNCTIONSETUP;
-	
+
 	return &fCounter;
 }
 
 void DataProxy::setEndcount()
 {
 	FUNCTIONSETUP;
-	
+
 	fCounter.setEndCount( fRecords.size() );
 }
 
 void DataProxy::setIterateMode( const Mode m )
 {
 	FUNCTIONSETUP;
-	
+
 	fMode = m;
 }
 
@@ -143,6 +143,12 @@ Record* DataProxy::find( const QString &id ) const
 	return fRecords.value( id );
 }
 
+QList<Record*> DataProxy::findByDescription( const QString &description ) const
+{
+	FUNCTIONSETUP;
+	return fRecordsByDescription.values( description );
+}
+
 void DataProxy::resetIterator()
 {
 	fIterator = QMapIterator<QString, Record*>( fRecords );
@@ -151,7 +157,7 @@ void DataProxy::resetIterator()
 bool DataProxy::hasNext() const
 {
 	FUNCTIONSETUP;
-	
+
 	if( fMode == All )
 	{
 		return fIterator.hasNext();
@@ -198,15 +204,15 @@ Record* DataProxy::next()
 bool DataProxy::commit()
 {
 	FUNCTIONSETUP;
-	
+
 	// Commit created records.
 	QStringListIterator it( fCreated.keys() );
-	
+
 	DEBUGKPILOT << "Committing: [" << fCreated.size() << "] records.";
-	
+
 	// Reset the map
 	fCreated.clear();
-	
+
 	while( it.hasNext() )
 	{
 		QString id = it.next();
@@ -222,9 +228,10 @@ bool DataProxy::commit()
 				// Commit failed.
 				return false;
 			}
-			
+
 			// Commit succeeded.
-			
+
+			DEBUGKPILOT << "Record with tempId " << id << " committed with permId " << rec->id();
 			// Put the record with the new id in.
 			if( rec->id() != id )
 			{
@@ -233,7 +240,7 @@ bool DataProxy::commit()
 				
 				fRecords.remove( id );
 				fRecords.insert( rec->id(), rec );
-			
+
 				fChangedIds.insert( id, rec->id() );
 			}
 			else
@@ -249,17 +256,17 @@ bool DataProxy::commit()
 	
 	// Commit updated records.
 	DEBUGKPILOT << "Updating: [" << fOldRecords.size() << "] records.";
-	
+
 	QListIterator<Record*> i( fOldRecords.values() );
 	while( i.hasNext() )
 	{
 		// i.next() contains the old values.
 		Record *oldRec = i.next();
 		QString id = oldRec->id();
-		
+
 		// Look up the new values
 		Record *rec = find( id );
-		
+
 		if( rec && !fCreated.value( id ) )
 		{
 			if( !commitUpdate( rec ) )
@@ -267,11 +274,11 @@ bool DataProxy::commit()
 				// Commit failed.
 				return false;
 			}
-			
+
 			// Commit succeeded.
-			
+
 			QString newId = rec->id();
-			
+
 			if( newId != id )
 			{
 				oldRec->setId( newId );
@@ -284,7 +291,7 @@ bool DataProxy::commit()
 	
 	// Commit deleted records
 	DEBUGKPILOT << "Deleting: [" << fDeletedRecords.size() << "] records.";
-	
+
 	i = QListIterator<Record*>( fDeletedRecords.values() );
 	while( i.hasNext() )
 	{
@@ -300,13 +307,13 @@ bool DataProxy::commit()
 				// Commit failed.
 				return false;
 			}
-			
+
 			// Commit succeeded.
-			
+
 			fDeleted.insert( oldRec->id(), true );
 		}
 	}
-	
+
 	// Give implementing classes the change to do things if necessary.
 	return _commit();
 }
@@ -314,28 +321,28 @@ bool DataProxy::commit()
 bool DataProxy::rollback()
 {
 	FUNCTIONSETUP;
-	
+
 	// Delete committed new records.
 	QStringListIterator it( fCreated.keys() );
-	
+
 	while( it.hasNext() )
 	{
 		QString id = it.next();
-		
+
 		// Only undo creates that are committed.
 		Record *rec = find( id );
 		if( rec && fCreated.value( id ) )
 		{
 			DEBUGKPILOT << "Deleting created record: [" << rec->id() << "].";
-			
+
 			commitDelete( rec );
 			fCreated.insert( rec->id(), false );
 		}
 	}
-	
+
 	// Reset the map
 	fCreated.clear();
-	
+
 	// Undo changes to updated records.
 	QListIterator<Record*> i( fOldRecords.values() );
 	while( i.hasNext() )
@@ -344,47 +351,47 @@ bool DataProxy::rollback()
 		if( fUpdated.value( oldRec->id() ) )
 		{
 			DEBUGKPILOT << "Restoring changed record: [" << oldRec->id() << "].";
-			
+
 			QString oldId = oldRec->id();
 			commitUpdate( oldRec );
-			
+
 			// Id might have changed
 			if( oldRec->id() != oldId )
 			{
 				fUpdated.remove( oldId );
-				
+
 				fChangedIds.insert( oldId, oldRec->id() );
 			}
-			
+
 			fUpdated.insert( oldRec->id(), false );
 		}
 	}
-	
+
 	// Restore deleted records.
 	i = QListIterator<Record*>( fDeletedRecords.values() );
 	while( i.hasNext() )
 	{
 		Record *oldRec = i.next();
-		
+
 		if( fDeleted.value( oldRec->id() ) )
 		{
 			DEBUGKPILOT << "Restoring deleted record: [" << oldRec->id() << "].";
-		
+
 			QString oldId = oldRec->id();
 			commitCreate( oldRec );
-			
+
 			// Id might have changed
 			if( oldRec->id() != oldId )
 			{
 				fDeleted.remove( oldId );
-				
+
 				fChangedIds.insert( oldId, oldRec->id() );
 			}
-			
+
 			fDeleted.insert( oldRec->id(), false );
 		}
 	}
-	
+
 	// Give implementing classes the change to rollback things if necessary.
 	return _rollback();
 }
