@@ -229,9 +229,10 @@ void RCHotSyncHHTest::testCUD()
 	U = cudPC->countUpdated();
 	D = cudPC->countDeleted();
 	
-	QCOMPARE( C, 2 ); // 6.5.{2, 8}
-	QCOMPARE( U, 4 ); // 6.5.{3, 9, 11, 16}
-	QCOMPARE( D, 5 ); // 6.5.{4, 10, 12, 15, 16}
+	QCOMPARE( C, 3 ); // 6.5.{2, 8, 11}
+	QCOMPARE( U, 3 ); // 6.5.{3, 9, 16}
+	QCOMPARE( D, 6 ); // 6.5.{4, 10, 11, 12, 15, 16}
+
 }
 
 void RCHotSyncHHTest::testCase_6_5_1()
