@@ -1,6 +1,6 @@
 /* memofile-conduit.cc			KPilot
 **
-** Copyright (C) 2004-2007 by Jason 'vanRijn' Kasper
+** Copyright (C) 2004-2007 by Jason 'vanRijn' Kasper <vR@movingparts.net>
 **
 ** This file does the actual conduit work.
 */
@@ -26,6 +26,7 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
+#include "memofile-conduit.h"
 
 #include "options.h"
 
@@ -46,7 +47,6 @@
 
 #include "pilotRecord.h"
 #include "pilotSerialDatabase.h"
-#include "memofile-conduit.h"
 #include "memofileSettings.h"
 
 
@@ -167,7 +167,7 @@ bool MemofileConduit::setAppInfo()
 
 	fCategories = map;
 
-	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; i++)
+	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; ++i)
 	{
 		if (fCategories.contains(i)) {
 			fMemoAppInfo->setCategoryName(i,fCategories[i]);
@@ -221,7 +221,7 @@ bool MemofileConduit::loadPilotCategories()
 	int _category_id=0;
 	int _category_num=0;
 
-	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; i++)
+	for (unsigned int i = 0; i < Pilot::CATEGORY_COUNT; ++i)
 	{
 		_category_name = fMemoAppInfo->categoryName(i);
 		if (!_category_name.isEmpty())
@@ -261,8 +261,8 @@ void MemofileConduit::getAllFromPilot()
 	PilotMemo *memo = 0;
 
 	while ((pilotRec = fDatabase->readRecordByIndex(currentRecord)) != NULL) {
+		memo = new PilotMemo(pilotRec);
 		if ((!pilotRec->isSecret()) || _sync_private) {
-			memo = new PilotMemo(pilotRec);
 			fMemoList.append(memo);
 
 			DEBUGKPILOT
