@@ -1,6 +1,8 @@
+#ifndef KPILOT_FILEINSTALLER_H
+#define KPILOT_FILEINSTALLER_H
 /* fileInstaller.h			KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 **
 ** This is a class that does "the work" of adding and deleting
@@ -30,12 +32,6 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
-#ifndef _KPILOT_FILEINSTALLER_H
-#define _KPILOT_FILEINSTALLER_H
-
-#include <qobject.h>
-
-
 class QStringList;
 class QString;
 
