@@ -1,6 +1,6 @@
 /* KPilot
 **
-** Copyright (C) 1998-2001 by Dan Pilone
+** Copyright (C) 1998-2001 by Dan Pilone <dan@kpilot.org>
 ** Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 **
 ** This is a C++ wrapper for the Pilot's datebook structures.
@@ -26,53 +26,62 @@
 /*
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
-
-#include "options.h"
+#include "pilotDateEntry.h"
 
 #include <stdlib.h>
 
-#include <qtextcodec.h>
-#include <qdatetime.h>
+#include <QtCore/QDateTime>
+#include <QtCore/QRegExp>
 
 #include <kglobal.h>
-#include <kdebug.h>
-#include "libkcal/event.h"
 
-#include "pilotDateEntry.h"
+#include <config-kpilot.h>
 
-static const char *pilotDateEntry_id = "$Id: pilotDateEntry.cc 437980 2005-07-23 19:53:57Z kainhofe $";
-const int PilotDateEntry::APP_BUFFER_SIZE = 0xffff;
+#include "options.h"
+
+static const char *default_date_category_names[] = {
+	"Unfiled",
+	"Business",
+	"Personal",
+	0L
+} ;
+
+void PilotDateInfo::resetToDefault()
+{
+	FUNCTIONSETUP;
+	// Reset to all 0s
+	memset(&fInfo,0,sizeof(fInfo));
+	// Fill up default categories
+	for (unsigned int i=0; (i<4) && default_date_category_names[i]; ++i)
+	{
+		strncpy(fInfo.category.name[i],default_date_category_names[i],sizeof(fInfo.category.name[0]));
+	}
+
+	fInfo.startOfWeek = 0;
+
+}
 
 
-PilotDateEntry::PilotDateEntry(struct AppointmentAppInfo &appInfo):PilotAppCategory(), fAppInfo(appInfo)
+PilotDateEntry::PilotDateEntry():PilotRecordBase()
 {
 	::memset(&fAppointmentInfo, 0, sizeof(struct Appointment));
 }
 
 /* initialize the entry from another one. If rec==NULL, this constructor does the same as PilotDateEntry()
 */
-PilotDateEntry::PilotDateEntry(struct AppointmentAppInfo &appInfo, PilotRecord * rec) :
-	PilotAppCategory(rec),
-	fAppInfo(appInfo)
+PilotDateEntry::PilotDateEntry(PilotRecord * rec) :
+	PilotRecordBase(rec)
 {
 	::memset(&fAppointmentInfo, 0, sizeof(fAppointmentInfo));
 	if (rec)
 	{
-#if PILOT_LINK_NUMBER >= PILOT_LINK_0_12_0
-		pi_buffer_t b;
-		b.data = (unsigned char *) rec->getData();
-		b.allocated = b.used = rec->size();
+		// Construct a fake pi_buffer for unpack_Appointment.
+		// No ownership changes occur here.
+		pi_buffer_t b = { (unsigned char *) rec->data(), rec->size(), rec->size() } ;
 		unpack_Appointment(&fAppointmentInfo, &b, datebook_v1);
-#else
-		unpack_Appointment(&fAppointmentInfo,
-			(unsigned char *) rec->data(), rec->size());
-#endif
 	}
 	return;
 
-	/* NOTREACHED */
-	/* Included to avoid warning that id isn't used. */
-	(void) pilotDateEntry_id;
 }
 
 void PilotDateEntry::_copyExceptions(const PilotDateEntry & e)
@@ -93,9 +102,7 @@ void PilotDateEntry::_copyExceptions(const PilotDateEntry & e)
 		}
 		else
 		{
-			kdError() << __FUNCTION__
-				<< ": malloc() failed, exceptions not copied"
-				<< endl;
+			WARNINGKPILOT << "malloc() failed, exceptions not copied";
 			fAppointmentInfo.exceptions = 0;
 		}
 	}
@@ -108,8 +115,7 @@ void PilotDateEntry::_copyExceptions(const PilotDateEntry & e)
 
 
 PilotDateEntry::PilotDateEntry(const PilotDateEntry & e) :
-	PilotAppCategory(e),
-	fAppInfo(e.fAppInfo)
+	PilotRecordBase(e)
 {
 	::memcpy(&fAppointmentInfo, &e.fAppointmentInfo,
 		sizeof(struct Appointment));
@@ -154,12 +160,12 @@ PilotDateEntry & PilotDateEntry::operator = (const PilotDateEntry & e)
 }				// end of assignment operator
 
 
-QString PilotDateEntry::getTextRepresentation(bool richText)
+QString PilotDateEntry::getTextRepresentation(Qt::TextFormat richText)
 {
 	QString text, tmp;
-	QString par = richText?CSL1("<p>"):QString::null;
-	QString ps = richText?CSL1("</p>"):CSL1("\n");
-	QString br = richText?CSL1("<br/>"):CSL1("\n");
+	QString par = (richText==Qt::RichText) ?CSL1("<p>"):QString();
+	QString ps = (richText==Qt::RichText) ?CSL1("</p>"):CSL1("\n");
+	QString br = (richText==Qt::RichText) ?CSL1("<br/>"):CSL1("\n");
 
 	// title + name
 	text += par;
@@ -170,7 +176,7 @@ QString PilotDateEntry::getTextRepresentation(bool richText)
 	QDateTime dt(readTm(getEventStart()));
 	QString startDate(dt.toString(Qt::LocalDate));
 	text+=par;
-	text+=i18n("Start date: %1").arg(startDate);
+	text+=i18n("Start date: %1",startDate);
 	text+=ps;
 
 	if (isEvent())
@@ -184,42 +190,40 @@ QString PilotDateEntry::getTextRepresentation(bool richText)
 		dt=readTm(getEventEnd());
 		QString endDate(dt.toString(Qt::LocalDate));
 		text+=par;
-		text+=i18n("End date: %1").arg(endDate);
+		text+=i18n("End date: %1",endDate);
 		text+=ps;
 	}
 
 	if ( isAlarmEnabled() )
 	{
 		text+=par;
-		tmp=i18n("%1 is the duration, %2 is the time unit", "Alarm: %1 %2 before event starts").
-			arg(getAdvance());
+		QString tmpArg;
 		switch (getAdvanceUnits())
 		{
-			case advMinutes: tmp=tmp.arg(i18n("minutes")); break;
-			case advHours: tmp=tmp.arg(i18n("hours")); break;
-			case advDays: tmp=tmp.arg(i18n("days")); break;
-			default: tmp=tmp.arg(QString::null); break;;
+			case advMinutes: tmpArg = i18nc("Number of minutes", "minutes"); break;
+			case advHours: tmpArg = i18nc("Number of hours", "hours"); break;
+			case advDays: tmpArg = i18nc("Number of days", "days"); break;
+			default: tmpArg.clear(); break;
 		}
-		text+=tmp;
+		tmp=i18nc("%1 is the duration, %2 is the time unit", "Alarm: %1 %2 before event starts",getAdvance(),tmpArg);
 		text+=ps;
 	}
 
 	if (getRepeatType() != repeatNone)
 	{
 		text+=par;
-		tmp=i18n("Recurrence: every %1 %2");
 		int freq = getRepeatFrequency();
-		tmp=tmp.arg(freq);
-
+		QString tmpStr;
 		switch(getRepeatType())
 		{
-			case repeatDaily: tmp=tmp.arg(i18n("day(s)")); break;
-			case repeatWeekly: tmp=tmp.arg(i18n("week(s)")); break;
+			case repeatDaily: tmpStr = i18nc("The weekday(s) on which the repeat occurs", "day(s)"); break;
+			case repeatWeekly: tmpStr = i18nc("The week(s) in which the repeat occurs", "week(s)"); break;
 			case repeatMonthlyByDay:
-			case repeatMonthlyByDate: tmp=tmp.arg(i18n("month(s)")); break;
-			case repeatYearly: tmp=tmp.arg(i18n("year(s)")); break;
-			default: tmp=tmp.arg(QString::null); break;
+			case repeatMonthlyByDate: tmpStr = i18nc("The month(s) in which the repeat occurs", "month(s)"); break;
+			case repeatYearly: tmpStr = i18nc("The year(s) in which the repeat occurs", "year(s)"); break;
+			default: tmpStr.clear(); break;
 		}
+		tmp=i18n("Recurrence: every %1 %2",freq,tmpStr);
 		text+=tmp;
 		text+=br;
 
@@ -230,8 +234,8 @@ QString PilotDateEntry::getTextRepresentation(bool richText)
 		}
 		else
 		{
-			dt = readTm(getRepeatEnd()).date();
-			text+=i18n("Until %1").arg(dt.toString(Qt::LocalDate));
+			dt = readTm(getRepeatEnd())/*.date()*/;
+			text+=i18n("Until %1",dt.toString(Qt::LocalDate));
 		}
 		text+=br;
 
@@ -255,7 +259,7 @@ QString PilotDateEntry::getTextRepresentation(bool richText)
 	{
 		text+=par;
 		text+=i18n("Exceptions:")+br;
-		for (int i = 0; i < getExceptionCount(); i++)
+		for (int i = 0; i < getExceptionCount(); ++i)
 		{
 			QDate exdt=readTm(getExceptions()[i]).date();
 			text+=exdt.toString(Qt::LocalDate);
@@ -268,7 +272,7 @@ QString PilotDateEntry::getTextRepresentation(bool richText)
 	{
 		text += richText?CSL1("<hr/>"):CSL1("-------------------------\n");
 		text+=par;
-		text+=richText?i18n("<b><em>Note:</em></b><br>"):i18n("Note:\n");
+		text+=richText?i18n("<b><em>Note:</em></b><br/>"):i18n("Note:\n");
 		text+=rtExpand(getNote(), richText);
 		text+=ps;
 	}
@@ -300,7 +304,10 @@ unsigned int PilotDateEntry::alarmLeadTime() const
 	if (!isAlarmEnabled()) return 0;
 
 	int adv = getAdvance();
-	if ( adv < 0 ) return 0; // Not possible to enter on the pilot
+	if ( adv < 0 )
+	{
+		return 0; // Not possible to enter on the pilot
+	}
 	unsigned int t = adv;
 	int u = getAdvanceUnits();
 
@@ -316,25 +323,20 @@ unsigned int PilotDateEntry::alarmLeadTime() const
 	return t;
 }
 
-QString PilotDateEntry::getCategoryLabel() const
-{
-	return codec()->toUnicode(fAppInfo.category.name[category()]);
-}
-
-void *PilotDateEntry::pack_(void *buf, int *len)
+PilotRecord *PilotDateEntry::pack() const
 {
 	int i;
 
-#if PILOT_LINK_NUMBER >= PILOT_LINK_0_12_0
-	pi_buffer_t b = { 0,0,0 } ;
-	i = pack_Appointment(&fAppointmentInfo, &b, datebook_v1);
-	memcpy(buf,b.data,kMin(i,*len));
-	*len = kMin(i,*len);
-#else
-	i = pack_Appointment(&fAppointmentInfo, (unsigned char *) buf, *len);
-	*len = i;
-#endif
-	return buf;
+	pi_buffer_t *b = pi_buffer_new( sizeof(fAppointmentInfo) );
+	i = pack_Appointment(const_cast<Appointment_t *>(&fAppointmentInfo), b, datebook_v1);
+	if (i<0)
+	{
+		// Generic error from the pack_*() functions.
+		return 0;
+	}
+
+	// pack_Appointment sets b->used
+	return new PilotRecord( b, this );
 }
 
 /* setExceptions sets a new set of exceptions. Note that
@@ -365,9 +367,7 @@ void PilotDateEntry::setDescriptionP(const char *desc, int l)
 		}
 		else
 		{
-			kdError() << __FUNCTION__
-				<< ": malloc() failed, description not set"
-				<< endl;
+			WARNINGKPILOT << "malloc() failed, description not set";
 		}
 	}
 	else
@@ -391,8 +391,7 @@ void PilotDateEntry::setNoteP(const char *note, int l)
 		}
 		else
 		{
-			kdError() << __FUNCTION__
-				<< ": malloc() failed, note not set" << endl;
+			WARNINGKPILOT << "malloc() failed, note not set";
 		}
 	}
 	else
@@ -403,23 +402,75 @@ void PilotDateEntry::setNoteP(const char *note, int l)
 
 void PilotDateEntry::setNote(const QString &s)
 {
-	QCString t = codec()->fromUnicode(s);
+	QByteArray t = Pilot::toPilot(s);
 	setNoteP( t.data(),t.length() );
 }
 
+void PilotDateEntry::setLocation(const QString &s)
+{
+	QString note = Pilot::fromPilot(getNoteP());
+	QRegExp rxp = QRegExp("^[Ll]ocation:[^\n]+\n");
+
+	// per QString docs, this covers null and 0 length
+	if( s.isEmpty() )
+	{
+		note.remove( rxp );
+	}
+	else
+	{
+		QString location = "Location: " + s + '\n';
+		int pos = note.indexOf(rxp);
+
+		if(pos >= 0)
+		{
+			note.replace( rxp, location );
+		}
+		else
+		{
+			note = location + note;
+			setNote( note );
+		}
+	}
+}
+
+QString PilotDateEntry::getLocation() const
+{
+	// Read the complete note here and not the filtered
+	// one from PilotDateEntry::getNote();
+	QString note = Pilot::fromPilot(getNoteP());
+	QRegExp rxp = QRegExp("^[Ll]ocation:[^\n]+\n");
+	int pos = note.indexOf(rxp, 0);
+
+	if(pos >= 0)
+	{
+		QString location = rxp.capturedTexts().first();
+		rxp = QRegExp("^[Ll]ocation:[\\s|\t]*");
+		location.remove( rxp );
+		location.remove( '\n' );
+		return location;
+	}
+	else
+	{
+		return "";
+	}
+}
+
 void PilotDateEntry::setDescription(const QString &s)
 {
-	QCString t = codec()->fromUnicode(s);
+	QByteArray t = Pilot::toPilot(s);
 	setDescriptionP( t.data(),t.length() );
 }
 
 QString PilotDateEntry::getNote() const
 {
-	return codec()->toUnicode(getNoteP());
+	QString note = Pilot::fromPilot(getNoteP());
+	QRegExp rxp = QRegExp("^[Ll]ocation:[^\n]+\n");
+	note.remove( rxp );
+	return note;
 }
 
 QString PilotDateEntry::getDescription() const
 {
-	return codec()->toUnicode(getDescriptionP());
+	return Pilot::fromPilot(getDescriptionP());
 }
 
