@@ -1,5 +1,5 @@
-#ifndef _KPILOT_PLUGIN_H
-#define _KPILOT_PLUGIN_H
+#ifndef KPILOT_PLUGIN_H
+#define KPILOT_PLUGIN_H
 /* KPilot
 **
 ** Copyright (C) 2001 by Dan Pilone <dan@kpilot.org>
@@ -29,9 +29,11 @@
 ** Bug reports and questions can be sent to kde-pim@kde.org
 */
 
+// KPilot headers
 #include "pilotLocalDatabase.h"
 #include "syncAction.h"
 
+// Qt headers
 #include <QtCore/QVariantList>
 
 /** @file
@@ -43,7 +45,7 @@
 */
 
 
-class QTabWidget;
+class KTabWidget;
 class KAboutData;
 
 class PilotDatabase;
@@ -56,7 +58,7 @@ namespace Pilot
 	* Bump this number every release to the current YYYYMMDD
 	* value.
 	*/
-	static const unsigned int PLUGIN_API = 20071023;
+	static const unsigned int PLUGIN_API = 20090624;
 }
 
 /**
@@ -140,7 +142,7 @@ public:
 	* @param data The KAboutData that is used.
 	*
 	*/
-	static  void addAboutPage(QTabWidget *w,
+	static  void addAboutPage(KTabWidget *w,
 		KAboutData *data=0L);
 
 	/**
