@@ -22,27 +22,26 @@
 #define RESOURCEXMLRPCCONFIG_H
 
 #include <kresources/configwidget.h>
-#include <kdepimmacros.h>
+#include "egroupware_export.h"
 
-class KIntSpinBox;
 class KLineEdit;
-class KURLRequester;
+class KUrlRequester;
 
 namespace KNotes {
 
-class KDE_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
+class KNOTES_XMLRPC_EXPORT ResourceXMLRPCConfig : public KRES::ConfigWidget
 { 
   Q_OBJECT
 
   public:
-    ResourceXMLRPCConfig( QWidget* parent = 0, const char* name = 0 );
+    ResourceXMLRPCConfig( QWidget* parent );
 
   public slots:
     void loadSettings( KRES::Resource* );
     void saveSettings( KRES::Resource* );
 
   private:
-    KURLRequester *mURL;
+    KUrlRequester *mURL;
     KLineEdit *mDomain;
     KLineEdit *mUser;
     KLineEdit *mPassword;
