@@ -23,7 +23,7 @@
 
 #include <libkdepim/progressmanager.h>
 
-#include <libkcal/resourcecached.h>
+#include <kcal/resourcecached.h>
 
 #include <kabc/locknull.h>
 #include <kio/job.h>
@@ -44,20 +44,19 @@ class ResourceGroupware : public ResourceCached
     Q_OBJECT
   public:
     ResourceGroupware();
-  
-    ResourceGroupware( const KConfig * );
+    ResourceGroupware( const KConfigGroup &group );
     virtual ~ResourceGroupware();
 
-    void readConfig( const KConfig *config );
-    void writeConfig( KConfig *config );
+    void readConfig( const KConfigGroup &group );
+    void writeConfig( KConfigGroup &group );
 
     GroupwarePrefsBase *prefs();
 
     bool doOpen();
     void doClose();
 
-    bool doLoad();
-    bool doSave();
+    bool doLoad( bool syncCache );
+    bool doSave( bool syncCache );
 
     KABC::Lock *lock();
 
@@ -69,7 +68,7 @@ class ResourceGroupware : public ResourceCached
   protected slots:
     void loadFinished();
 
-    void slotJobResult( KIO::Job * );
+    void slotJobResult( KJob * );
     void slotJobData( KIO::Job *, const QByteArray & );
 
     void cancelLoad();
