@@ -891,28 +891,28 @@ static QStringList phoneTypeToString( KABC::PhoneNumber::Type type )
     type = type & ~KABC::PhoneNumber::Work;
   }
 
-  // To support both "home1" and "home2", map Home+Pref to home1
+  // To support both "home1" and "home2", map Home+Pref to home2
   if ( ( type & KABC::PhoneNumber::Home ) && ( type & KABC::PhoneNumber::Pref ) )
   {
-      types << "home1";
+      types << "home2";
       type = type & ~KABC::PhoneNumber::Home;
       type = type & ~KABC::PhoneNumber::Pref;
   }
-  // To support both "business1" and "business2", map Work+Pref to business1
+  // To support both "business1" and "business2", map Work+Pref to business2
   if ( ( type & KABC::PhoneNumber::Work ) && ( type & KABC::PhoneNumber::Pref ) )
   {
-      types << "business1";
+      types << "business2";
       type = type & ~KABC::PhoneNumber::Work;
       type = type & ~KABC::PhoneNumber::Pref;
   }
 
 
   if ( type & KABC::PhoneNumber::Home )
-    types << "home2";
+    types << "home1";
   if ( type & KABC::PhoneNumber::Msg ) // Msg==messaging
     types << "company";
   if ( type & KABC::PhoneNumber::Work )
-    types << "business2";
+    types << "business1";
   if ( type & KABC::PhoneNumber::Pref )
     types << "primary";
   if ( type & KABC::PhoneNumber::Voice )
@@ -942,13 +942,13 @@ static KABC::PhoneNumber::Type phoneTypeFromString( const QString& type )
     return KABC::PhoneNumber::Home | KABC::PhoneNumber::Fax;
   if ( type == "businessfax" )
     return KABC::PhoneNumber::Work | KABC::PhoneNumber::Fax;
-  if ( type == "business1" )
-    return KABC::PhoneNumber::Work | KABC::PhoneNumber::Pref;
   if ( type == "business2" )
+    return KABC::PhoneNumber::Work | KABC::PhoneNumber::Pref;
+  if ( type == "business1" )
     return KABC::PhoneNumber::Work;
-  if ( type == "home1" )
-    return KABC::PhoneNumber::Home | KABC::PhoneNumber::Pref;
   if ( type == "home2" )
+    return KABC::PhoneNumber::Home | KABC::PhoneNumber::Pref;
+  if ( type == "home1" )
     return KABC::PhoneNumber::Home;
   if ( type == "company" )
     return KABC::PhoneNumber::Msg;
@@ -1018,11 +1018,7 @@ void Contact::setFields( const KABC::Addressee* addressee, KABC::AddressBook* ad
   setOrganization( addressee->organization() );
   setWebPage( addressee->url().url() );
   setIMAddress( addressee->custom( "KADDRESSBOOK", "X-IMAddress" ) );
-#if KDE_IS_VERSION(3,5,8)
   setDepartment( addressee->department());
-#else
-  setDepartment( addressee->custom( "KADDRESSBOOK", "X-Department" ) );
-#endif
   setOfficeLocation( addressee->custom( "KADDRESSBOOK", "X-Office" ) );
   setProfession( addressee->custom( "KADDRESSBOOK", "X-Profession" ) );
   setRole( addressee->role() );
@@ -1259,7 +1255,7 @@ QImage Contact::loadPictureFromKMail( const QString& attachmentName, KABC::Resou
   QImage img;
   KUrl url;
   if ( resource->kmailGetAttachment( url, subResource, sernum, attachmentName ) && !url.isEmpty() ) {
-    const QString path = url.path();
+    const QString path = url.toLocalFile();
     img.load( path );
     QFile::remove(path);
   }
@@ -1285,7 +1281,7 @@ QByteArray Kolab::Contact::loadDataFromKMail( const QString& attachmentName, KAB
   QByteArray data;
   KUrl url;
   if ( resource->kmailGetAttachment( url, subResource, sernum, attachmentName ) && !url.isEmpty() ) {
-    QFile f( url.path() );
+    QFile f( url.toLocalFile() );
     if ( f.open( QIODevice::ReadOnly ) ) {
       data = f.readAll();
       f.close();
