@@ -25,9 +25,12 @@
 #include "ldapdialog.h"
 
 LdapDialog::LdapDialog( QWidget *parent )
-  : KDialogBase( parent, "", true, "", Ok | Cancel, Ok, true )
+  : KDialog( parent )
 {
   setCaption( i18n( "User Account Selection" ) );
+  setButtons( Ok | Cancel );
+  setDefaultButton( Ok );
+  showButtonSeparator( true );
 
   mView = new LdapView( this );
   setMainWidget( mView );
