@@ -19,23 +19,31 @@
  *
  */
 
-#include <cassert>
-#include "edithistorydialog.h"
-#include <fcntl.h>
-#include <kcal/incidence.h>
-#include <KApplication>       // kapp
 #include "karmstorage.h"
-#include "karmutility.h"
-#include <KDebug>
+#include "edithistorydialog.h"
+#include "ktimetrackerutility.h"
+#include "ktimetracker.h"
+#include "storageadaptor.h"
+#include "task.h"
+#include "taskview.h"
+#include "timekard.h"
+
 #include <kemailsettings.h>
+#include <kpimprefs.h>        // for timezone
+#include <kio/netaccess.h>
+#include <kcal/resourcecalendar.h>
+#include <kcal/resourcelocal.h>
+#include <resourceremote.h>
+#include <kcal/incidence.h>
+
+#include <KApplication>       // kapp
+#include <KDebug>
 #include <KLocale>            // i18n
 #include <KMessageBox>
-#include <kpimprefs.h>        // for timezone
 #include <KProgressDialog>
 #include <KTemporaryFile>
-#include "ktimetracker.h"
 #include <KUrl>
-#include <kio/netaccess.h>
+
 #include <QByteArray>
 #include <QDateTime>
 #include <QFile>
@@ -46,16 +54,12 @@
 #include <QStringList>
 #include <QTableWidget>
 #include <QTextStream>
-#include <kcal/resourcecalendar.h>
-#include <kcal/resourcelocal.h>
-#include <resourceremote.h>
+
 #include <sys/stat.h>
-#include "storageadaptor.h"
-#include "task.h"
-#include "taskview.h"
-#include "timekard.h"
 #include <sys/types.h>
 #include <unistd.h>
+#include <cassert>
+#include <fcntl.h>
 
 
 //@cond PRIVATE
@@ -109,7 +113,7 @@ QString KarmStorage::load( TaskView* view, const QString &fileName )
     }
   }
 
-  if ( d->mCalendar)
+  if ( d->mCalendar )
     closeStorage();
 
   // Create local file resource and add to resources
@@ -156,7 +160,7 @@ QString KarmStorage::load( TaskView* view, const QString &fileName )
     kDebug(5970) << "KarmStorage::load"
       << "rawTodo count (includes completed todos) ="
       << todoList.count();
-    for( todo = todoList.begin(); todo != todoList.end(); ++todo )
+    for( todo = todoList.constBegin(); todo != todoList.constEnd(); ++todo )
     {
       Task* task = new Task(*todo, view);
       map.insert( (*todo)->uid(), task );
@@ -165,7 +169,7 @@ QString KarmStorage::load( TaskView* view, const QString &fileName )
     }
 
     // Load each task under it's parent task.
-    for( todo = todoList.begin(); todo != todoList.end(); ++todo )
+    for( todo = todoList.constBegin(); todo != todoList.constEnd(); ++todo )
     {
       Task* task = map.value( (*todo)->uid() );
 
@@ -200,12 +204,12 @@ Task* KarmStorage::task( const QString& uid, TaskView* view )
   KCal::Todo::List todoList;
   KCal::Todo::List::ConstIterator todo;
   todoList = d->mCalendar->rawTodos();
-  todo = todoList.begin();
+  todo = todoList.constBegin();
   Task* result=0;
   bool konsolemode=false;
   if ( view == 0 ) konsolemode=true;
-  while ( todo != todoList.end() && ( (*todo)->uid() != uid ) ) ++todo;
-  if ( todo != todoList.end() ) result = new Task((*todo), view, konsolemode);
+  while ( todo != todoList.constEnd() && ( (*todo)->uid() != uid ) ) ++todo;
+  if ( todo != todoList.constEnd() ) result = new Task((*todo), view, konsolemode);
   kDebug(5970) << "Leaving function, returning " << result;
   return result;
 }
@@ -229,10 +233,11 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
 
   // remember tasks that are running and their start times
   QTreeWidgetItemIterator it( view );
-  while ( *it ) 
+  while ( *it )
   {
     Task *task = static_cast< Task* >( *it );
-    if ( task->isRunning() ) {
+    if ( task->isRunning() )
+    {
       runningTasks.append( task->uid() );
       startTimes.append( task->startTime() );
     }
@@ -241,7 +246,7 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
 
   view->clear();
   todoList = rc->rawTodos();
-  for( todo = todoList.begin(); todo != todoList.end(); ++todo )
+  for ( todo = todoList.constBegin(); todo != todoList.constEnd(); ++todo )
   {
     Task* task = new Task(*todo, view);
     task->setWhatsThis(0,"The task name is how you call the task, it can be chosen freely.");
@@ -252,7 +257,7 @@ QString KarmStorage::buildTaskView(KCal::ResourceCalendar *rc, TaskView *view)
   }
 
   // 1.1. Load each task under it's parent task.
-  for( todo = todoList.begin(); todo != todoList.end(); ++todo )
+  for( todo = todoList.constBegin(); todo != todoList.constEnd(); ++todo )
   {
     Task* task = map.value( (*todo)->uid() );
     // No relatedTo incident just means this is a top-level task.
@@ -308,6 +313,12 @@ KCal::Event::List KarmStorage::rawevents()
   return d->mCalendar->rawEvents();
 }
 
+KCal::Todo::List KarmStorage::rawtodos()
+{
+  kDebug(5970) << "Entering function";
+  return d->mCalendar->rawTodos();
+}
+
 bool KarmStorage::allEventsHaveEndTiMe(Task* task)
 {
   kDebug(5970) << "Entering function";
@@ -326,6 +337,19 @@ bool KarmStorage::allEventsHaveEndTiMe(Task* task)
   return true;
 }
 
+bool KarmStorage::allEventsHaveEndTiMe()
+{
+  kDebug(5970) << "Entering function";
+  KCal::Event::List eventList = d->mCalendar->rawEvents();
+  for(KCal::Event::List::iterator i = eventList.begin();
+      i != eventList.end();
+      ++i)
+  {
+    if ( !(*i)->hasEndDate() ) return false;
+  }
+  return true;
+}
+
 QString KarmStorage::save(TaskView* taskview)
 {
   kDebug(5970) << "Entering function";
@@ -334,7 +358,7 @@ QString KarmStorage::save(TaskView* taskview)
   QStack<KCal::Todo*> parents;
   if ( taskview ) // we may also be in konsole mode
   {
-    for (int i = 0; i < taskview->topLevelItemCount(); ++i ) 
+    for (int i = 0; i < taskview->topLevelItemCount(); ++i )
     {
       Task *task = static_cast< Task* >( taskview->topLevelItem( i ) );
       kDebug( 5970 ) << "write task" << task->name();
@@ -385,7 +409,7 @@ QString KarmStorage::writeTaskAsTodo(Task* task, QStack<KCal::Todo*>& parents )
   if ( !parents.isEmpty() ) todo->setRelatedTo( parents.top() );
   parents.push( todo );
 
-  for ( int i = 0; i < task->childCount(); ++i ) 
+  for ( int i = 0; i < task->childCount(); ++i )
   {
     Task *nextTask = static_cast< Task* >( task->child( i ) );
     err = writeTaskAsTodo( nextTask, parents );
@@ -496,7 +520,7 @@ QString KarmStorage::exportcsvFile( TaskView *taskview,
   // save, either locally or remote
   if ((rc.url.isLocalFile()) || (!rc.url.url().contains("/")))
   {
-    QString filename=rc.url.path();
+    QString filename=rc.url.toLocalFile();
     if (filename.isEmpty()) filename=rc.url.url();
     QFile f( filename );
     if( !f.open( QIODevice::WriteOnly ) ) {
@@ -699,7 +723,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
   else
   {
     itab->setItem(0,0,new QTableWidgetItem("Task name"));
-    for ( QDate mdate=from; mdate.daysTo(to)>=0; mdate=mdate.addDays(1) ) 
+    for ( QDate mdate=from; mdate.daysTo(to)>=0; mdate=mdate.addDays(1) )
     {
       kDebug(5970) << mdate.toString();
       itab->setItem(0,1+from.daysTo(mdate),new QTableWidgetItem(mdate.toString()));
@@ -717,7 +741,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
             kDebug(5970) << "found an event for task, event=" << (*i)->uid();
             // dtStart is stored like DTSTART;TZID=Europe/Berlin:20080327T231056
             // dtEnd is stored like DTEND:20080327T231509Z
-            // we need to subtract the offset from UTC.  
+            // we need to subtract the offset from UTC.
             KDateTime startTime=(*i)->dtStart().addSecs((*i)->dtStart().utcOffset());
             KDateTime endTime=(*i)->dtEnd().addSecs((*i)->dtEnd().utcOffset());
             KDateTime NextMidNight=startTime;
@@ -743,7 +767,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
             itab->setItem(n+1,from.daysTo(mdate)+1,new QTableWidgetItem(QString::number(secondsSum)));
           };
         }
-      } 
+      }
     }
     // use the internal table itab to create the return value retval
     for ( int y=0; y<=(taskview->count()); y++ )
@@ -754,7 +778,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
         retval.append(rc.delimiter);
         if (y>0)
         {
-          if (itab->item(y,x)) 
+          if (itab->item(y,x))
           {
             kDebug(5970) << "itab->item(y,x)=" << itab->item(y,x)->text();
             retval.append(formatTime( itab->item(y,x)->text().toInt()/60.0, rc.decimalMinutes ));
@@ -778,10 +802,10 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
     if ((rc.url.isLocalFile()) || (!rc.url.url().contains("/")))
     {
       kDebug(5970) << "storing a local file";
-      QString filename=rc.url.path();
+      QString filename=rc.url.toLocalFile();
       if (filename.isEmpty()) filename=rc.url.url();
       QFile f( filename );
-      if( !f.open( QIODevice::WriteOnly ) ) 
+      if( !f.open( QIODevice::WriteOnly ) )
       {
         err = i18n( "Could not open \"%1\".", filename );
         kDebug(5970) << "Could not open file";
@@ -795,7 +819,7 @@ QString KarmStorage::exportcsvHistory ( TaskView      *taskview,
         stream << retval;
         f.close();
       }
-    } 
+    }
     else // use remote file
     {
       KTemporaryFile tmpFile;
@@ -831,7 +855,7 @@ void KarmStorage::startTimer( QString taskID )
   KCal::Todo::List todoList;
   KCal::Todo::List::ConstIterator todo;
   todoList = d->mCalendar->rawTodos();
-  for( todo = todoList.begin(); todo != todoList.end(); ++todo )
+  for( todo = todoList.constBegin(); todo != todoList.constEnd(); ++todo )
   {
     kDebug(5970) << (*todo)->uid();
     kDebug(5970) << taskID;
@@ -866,7 +890,7 @@ void KarmStorage::stopTimer( const Task* task, const QDateTime &when )
 	kDebug() << "kwhen ==" <<  kwhen;
         (*i)->setDtEnd(kwhen);
       }
-      else 
+      else
       {
         kDebug(5970) << "this event has an enddate";
         kDebug(5970) << "end date is " << (*i)->dtEnd();
@@ -997,11 +1021,11 @@ QList<HistoryEvent> KarmStorage::getHistory(const QDate& from,
 
   for( QDate date = from; date <= to; date = date.addDays( 1 ) ) {
     events = d->mCalendar->rawEventsForDate( date, KPIM::KPimPrefs::timeSpec() );
-    for (event = events.begin(); event != events.end(); ++event) 
+    for (event = events.begin(); event != events.end(); ++event)
     {
 
       // KArm events have the custom property X-KDE-Karm-duration
-      if (! processed.contains( (*event)->uid())) 
+      if (! processed.contains( (*event)->uid()))
       {
         // If an event spans multiple days, CalendarLocal::rawEventsForDate
         // will return the same event on both days.  To avoid double-counting
@@ -1017,7 +1041,7 @@ QList<HistoryEvent> KarmStorage::getHistory(const QDate& from,
           QByteArray( "duration" )) == QString::null && (*event)->customProperty( "karm",
           QByteArray( "duration" )) != QString::null )
 
-          (*event)->setCustomProperty(  
+          (*event)->setCustomProperty(
             KGlobal::mainComponent().componentName().toUtf8(),
             QByteArray( "duration" ), (*event)->customProperty( "karm",
             QByteArray( "duration" )));
@@ -1057,7 +1081,7 @@ bool KarmStorage::remoteResource( const QString& file ) const
 {
   kDebug(5970) << "Entering function";
   QString f = file.toLower();
-  bool rval = f.startsWith( "http://" ) || f.startsWith( "ftp://" );
+  bool rval = f.startsWith( QLatin1String("http://") ) || f.startsWith( QLatin1String("ftp://") );
 
   kDebug(5970) << "KarmStorage::remoteResource(" << file <<" ) returns" << rval;
   return rval;
@@ -1070,7 +1094,7 @@ QString KarmStorage::saveCalendar()
   KABC::Lock *lock = d->mCalendar->lock();
   if ( !lock || !lock->lock() ) err=QString("Could not save. Could not lock file.");
 
-  if ( d->mCalendar->save() ) 
+  if ( d->mCalendar->save() )
   {
     lock->unlock();
   }
