@@ -32,7 +32,7 @@
 
 #include <kcal/event.h>
 
-#include "karmutility.h"
+#include "ktimetrackerutility.h"
 #include "ktimetracker.h"
 #include "preferences.h"
 
@@ -184,7 +184,8 @@ void Task::setRunning( bool on, KarmStorage* storage, const QDateTime &when )
 
 void Task::resumeRunning()
 // setRunning is the back-end, the front-end is StartTimerFor().
-// resumeRunning is the same as setRunning, but with no storage access.
+// resumeRunning does the same as setRunning, but not add a new 
+// start date to the storage.
 {
   kDebug(5970) << "Entering function"; 
   if (!mTimer->isActive()) 
@@ -346,6 +347,29 @@ QString Task::setSessionTime( long minutes )
   return err;
 }
 
+QString Task::recalculatetotalsessiontime()
+              {
+                  QString result;
+                  setTotalSessionTime(0);
+                  Task* child;
+                  for (int i=0; i<this->childCount(); ++i)
+                      child=(Task*)this->child(i);
+                  addTotalSessionTime(time());
+                  return result;
+              }
+
+long Task::recalculatetotaltime()
+{
+  long result=0;
+  setTotalTime(0);
+  Task* child;
+  for (int i=0; i<this->childCount(); ++i)
+    child=(Task*)this->child(i);
+  addTotalTime(time());
+  result=totalTime();
+  return result;
+}
+
 void Task::changeTimes( long minutesSession, long minutes, KarmStorage* storage)
 {
   kDebug(5970) << "Entering function";
@@ -647,26 +671,6 @@ QDateTime Task::startTime() const
   return mLastStart;
 }
 
-long Task::time() const
-{
-  return mTime;
-}
-
-long Task::totalTime() const
-{
-  return mTotalTime;
-}
-
-long Task::sessionTime() const
-{
-  return mSessionTime;
-}
-
-long Task::totalSessionTime() const
-{
-  return mTotalSessionTime;
-}
-
 KDateTime Task::sessionStartTiMe() const
 {
   return mSessionStartTiMe;
