@@ -571,6 +571,8 @@ QString TaskView::reFreshTimes()
       }
     }
   }
+  for (int i=0; i<count(); i++) itemAt(i)->recalculatetotaltime();
+  for (int i=0; i<count(); i++) itemAt(i)->recalculatetotalsessiontime();
   refresh();
   kDebug(5970) << "Leaving TaskView::reFreshTimes()";
   return err;
@@ -671,6 +673,12 @@ QString TaskView::save()
   return err;
 }
 
+void TaskView::dropEvent ( QDropEvent * event )
+{
+  QTreeWidget::dropEvent(event);
+  reFreshTimes();
+}
+
 void TaskView::startCurrentTimer()
 {
   startTimerFor( currentItem() );
