@@ -21,27 +21,27 @@
 
 #include "groupwarejob.h"
 
+#include <KDebug>
 #include <kio/job.h>
-#include <kdebug.h>
 
 using namespace KIO;
 
-KIO::TransferJob *GroupwareJob::getCalendar( const KURL &u )
+KIO::TransferJob *GroupwareJob::getCalendar( const KUrl &u )
 {
-  KURL url = u;
+  KUrl url = u;
   url.setPath( "/calendar/" );
 
-  kdDebug() << "GroupwareJob::getCalendar(): URL: " << url << endl;
+  kDebug() <<"GroupwareJob::getCalendar(): URL:" << url;
 
-  return KIO::get( url, false, false );
+  return KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
 }
 
-KIO::TransferJob *GroupwareJob::getAddressBook( const KURL &u )
+KIO::TransferJob *GroupwareJob::getAddressBook( const KUrl &u )
 {
-  KURL url = u;
+  KUrl url = u;
   url.setPath( "/addressbook/" );
 
-  kdDebug() << "GroupwareJob::getAddressBook(): URL: " << url << endl;
+  kDebug() <<"GroupwareJob::getAddressBook(): URL:" << url;
 
-  return KIO::get( url, false, false );
+  return KIO::get( url, KIO::NoReload, KIO::HideProgressInfo );
 }
