@@ -20,11 +20,7 @@
 #include "kaddrbookexternal.h"
 #include "kaddressbookcore_interface.h"
 
-#ifdef KDEPIM_NEW_DISTRLISTS
-#include "distributionlist.h"
-#else
 #include <kabc/distributionlist.h>
-#endif
 #include <kabc/resource.h>
 #include <kabc/stdaddressbook.h>
 #include <kabc/vcardconverter.h>
@@ -98,13 +94,13 @@ void KAddrBookExternal::addEmail( const QString &addr, QWidget *parent )
 
     if ( KAddrBookExternal::addAddressee( a ) ) {
       QString text = i18n( "<qt>The email address <b>%1</b> was added to your "
-                           "addressbook; you can add more information to this "
-                           "entry by opening the addressbook.</qt>", addr );
+                           "address book; you can add more information to this "
+                           "entry by opening the address book.</qt>", addr );
       KMessageBox::information( parent, text, QString(), "addedtokabc" );
     }
   } else {
     QString text =
-      i18n( "<qt>The email address <b>%1</b> is already in your addressbook.</qt>", addr );
+      i18n( "<qt>The email address <b>%1</b> is already in your address book.</qt>", addr );
     KMessageBox::information( parent, text, QString(), "alreadyInAddressBook" );
   }
   ab->setErrorHandler( 0 );
@@ -136,16 +132,16 @@ bool KAddrBookExternal::addVCard( const KABC::Addressee &addressee, QWidget *par
 
   if ( addressees.isEmpty() ) {
     if ( KAddrBookExternal::addAddressee( addressee ) ) {
-      QString text = i18n( "The VCard was added to your addressbook; "
+      QString text = i18n( "The VCard was added to your address book; "
                            "you can add more information to this "
-                           "entry by opening the addressbook." );
+                           "entry by opening the address book." );
       KMessageBox::information( parent, text, QString(), "addedtokabc" );
       inserted = true;
     }
   } else {
     QString text = i18n( "The VCard's primary email address is already in "
-                         "your addressbook; however, you may save the VCard "
-                         "into a file and import it into the addressbook manually." );
+                         "your address book; however, you may save the VCard "
+                         "into a file and import it into the address book manually." );
     KMessageBox::information( parent, text );
     inserted = true;
   }
@@ -158,14 +154,6 @@ bool KAddrBookExternal::addAddressee( const KABC::Addressee &addr )
 {
   KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
 
-  // PORT. FIXME: This ugly hack will be removed in 4.0
-  while ( !addressBook->loadingHasFinished() ) {
-    qApp->processEvents( QEventLoop::ExcludeUserInputEvents );
-
-    // use sleep here to reduce cpu usage
-    usleep( 100 );
-  }
-
   // Select a resource
   QList<KABC::Resource*> kabcResources = addressBook->resources();
   QList<KRES::Resource*> kresResources;
@@ -180,10 +168,10 @@ bool KAddrBookExternal::addAddressee( const KABC::Addressee &addr )
       }
     }
   }
-
   kabcResource =
     static_cast<KABC::Resource*>( KRES::SelectDialog::getResource( kresResources, 0 ) );
-
+  if( !kabcResource ) 
+    return false;
   KABC::Ticket *ticket = addressBook->requestSaveTicket( kabcResource );
   bool saved = false;
   if ( ticket ) {
@@ -209,18 +197,10 @@ QString KAddrBookExternal::expandDistributionList( const QString &listName )
 
   const QString lowerListName = listName.toLower();
   KABC::AddressBook *addressBook = KABC::StdAddressBook::self( true );
-#ifdef KDEPIM_NEW_DISTRLISTS
-  KPIM::DistributionList distrList =
-    KPIM::DistributionList::findByName( addressBook, lowerListName, false );
-  if ( !distrList.isEmpty() ) {
-    return distrList.emails( addressBook ).join( ", " );
-  }
-#else
   KABC::DistributionList* list = addressBook->findDistributionListByName( listName, Qt::CaseInsensitive );
 
   if ( list ) {
     return list->emails().join( ", " );
   }
-#endif
   return QString();
 }
