@@ -22,16 +22,16 @@
 #ifndef TESTDATEEDIT_H
 #define TESTDATEEDIT_H
 
-#include <qwidget.h>
+#include <QWidget>
 
 class DateEdit : public QWidget
 {
   Q_OBJECT
 
   public:
-    DateEdit( QWidget *parent = 0, const char *name = 0 );
+    DateEdit( QWidget *parent = 0 );
 
-  public slots:
+  public Q_SLOTS:
     void dateChanged( const QDate& );
 };
 
