@@ -3,8 +3,6 @@
 // Contents:   Date parsing function
 // Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
 // WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
-// $Revision: 494852 $
-// $Date: 2006-01-06 13:12:33 +0100 (Fr, 06 Jan 2006) $
 //
 // Copyright (c) 1996, 1997 Douglas W. Sauder
 // All rights reserved.
@@ -248,7 +246,7 @@ int ParseRfc822Date(const char *str, struct tm *tms, int *z)
     case 'O':
     case 'o':
         /* Oct */
-        if ((str[pos+1] == 'c' || str[pos+1] == 'c')
+        if ((str[pos+1] == 'c' || str[pos+1] == 'C')
             && (str[pos+2] == 't' || str[pos+2] == 'T')) {
             n = 9;
             pos += 3;
