@@ -3,8 +3,6 @@
 // Contents:   Definitions for DwPopClient
 // Maintainer: Doug Sauder <dwsauder@fwb.gulf.net>
 // WWW:        http://www.fwb.gulf.net/~dwsauder/mimepp.html
-// $Revision: 375351 $
-// $Date: 2005-01-04 00:27:53 +0100 (Di, 04 Jan 2005) $
 //
 // Copyright (c) 1996, 1997 Douglas W. Sauder
 // All rights reserved.
@@ -29,7 +27,7 @@
 #include <string.h>
 #include <stdlib.h>
 #include <mimelib/pop.h>
-#include <config.h>
+#include <kdefakes.h>
 
 #define POP_PORT 110
 #define RECV_BUFFER_SIZE  8192
